@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EventHandlerSDL2.cxx 2977 2014-08-15 15:13:00Z stephena $
+// $Id: EventHandlerSDL2.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -25,35 +25,12 @@ EventHandlerSDL2::EventHandlerSDL2(OSystem& osystem)
   : EventHandler(osystem)
 {
 }
- 
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EventHandlerSDL2::~EventHandlerSDL2()
 {
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void EventHandlerSDL2::initializeJoysticks()
-{
-#ifdef JOYSTICK_SUPPORT
-  // Initialize the joystick subsystem
-  if(SDL_WasInit(SDL_INIT_JOYSTICK) != 0)
-  {
-    if(SDL_NumJoysticks() > 0)
-    {
-      int numSticks = SDL_NumJoysticks();
-      for(int i = 0; i < numSticks; ++i)
-        addJoystick(new JoystickSDL2(i), i);
-
-      myOSystem.logMessage("EventHandlerSDL2::initializeJoysticks() +sticks", 2);
-    }
-    else
-      myOSystem.logMessage("EventHandlerSDL2::initializeJoysticks() -sticks", 2);
-  }
-  else
-    myOSystem.logMessage("EventHandlerSDL2::initializeJoysticks() failed!", 2);
-#endif
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EventHandlerSDL2::enableTextEvents(bool enable)
 {
@@ -64,7 +41,7 @@ void EventHandlerSDL2::enableTextEvents(bool enable)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const char* EventHandlerSDL2::nameForKey(StellaKey key)
+const char* EventHandlerSDL2::nameForKey(StellaKey key) const
 {
   return SDL_GetScancodeName(SDL_Scancode(key));
 }
@@ -157,6 +134,17 @@ void EventHandlerSDL2::pollEvent()
         handleJoyHatEvent(myEvent.jhat.which, myEvent.jhat.hat, value);
         break;  // SDL_JOYHATMOTION
       }
+
+      case SDL_JOYDEVICEADDED:
+      {
+        addJoystick(new JoystickSDL2(myEvent.jdevice.which));
+        break;  // SDL_JOYDEVICEADDED
+      }
+      case SDL_JOYDEVICEREMOVED:
+      {
+        removeJoystick(myEvent.jdevice.which);
+        break;  // SDL_JOYDEVICEREMOVED
+      }
   #endif
 
       case SDL_QUIT:
@@ -214,25 +202,29 @@ void EventHandlerSDL2::pollEvent()
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EventHandlerSDL2::JoystickSDL2::JoystickSDL2(int idx)
-  : myStick(NULL)
+  : myStick(nullptr)
 {
-#ifdef JOYSTICK_SUPPORT
   myStick = SDL_JoystickOpen(idx);
   if(myStick)
   {
-    initialize(SDL_JoystickName(myStick),
+    // There still seems to be some issue with certain controllers not being
+    // recognized.  In this case, SDL names the controller as "XInput Controller".
+    // This would be fine except it also appends " #x", where x seems to vary.
+    // Obviously this wreaks havoc with the idea that a joystick will always
+    // have the same name.  So we truncate the number.
+    const char* sdlname = SDL_JoystickName(myStick);
+    const string& desc = BSPF_startsWithIgnoreCase(sdlname, "XInput Controller")
+                         ? "XInput Controller" : sdlname;
+
+    initialize(SDL_JoystickInstanceID(myStick), desc,
         SDL_JoystickNumAxes(myStick), SDL_JoystickNumButtons(myStick),
         SDL_JoystickNumHats(myStick), SDL_JoystickNumBalls(myStick));
   }
-#endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EventHandlerSDL2::JoystickSDL2::~JoystickSDL2()
 {
-#ifdef JOYSTICK_SUPPORT
   if(myStick)
     SDL_JoystickClose(myStick);
-  myStick = NULL;
-#endif
 }
