@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: FrameBufferSDL2.cxx 2987 2014-09-01 21:17:33Z stephena $
+// $Id: FrameBufferSDL2.cxx 3154 2015-03-21 00:16:30Z stephena $
 //============================================================================
 
 #include <SDL.h>
@@ -36,10 +36,9 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FrameBufferSDL2::FrameBufferSDL2(OSystem& osystem)
   : FrameBuffer(osystem),
-    myWindow(NULL),
-    myRenderer(NULL),
-    myDirtyFlag(true),
-    myDblBufferedFlag(true)
+    myWindow(nullptr),
+    myRenderer(nullptr),
+    myDirtyFlag(true)
 {
   // Initialize SDL2 context
   if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_JOYSTICK) < 0)
@@ -47,7 +46,7 @@ FrameBufferSDL2::FrameBufferSDL2(OSystem& osystem)
     ostringstream buf;
     buf << "ERROR: Couldn't initialize SDL: " << SDL_GetError() << endl;
     myOSystem.logMessage(buf.str(), 0);
-    return;
+    throw "FATAL ERROR";
   }
   myOSystem.logMessage("FrameBufferSDL2::FrameBufferSDL2 SDL_Init()", 2);
 
@@ -66,19 +65,19 @@ FrameBufferSDL2::~FrameBufferSDL2()
   if(myRenderer)
   {
     SDL_DestroyRenderer(myRenderer);
-    myRenderer = NULL;
+    myRenderer = nullptr;
   }
   if(myWindow)
   {
     SDL_SetWindowFullscreen(myWindow, 0); // on some systems, a crash occurs
                                           // when destroying fullscreen window
     SDL_DestroyWindow(myWindow);
-    myWindow = NULL;
+    myWindow = nullptr;
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBufferSDL2::queryHardware(Common::Array<GUI::Size>& displays,
+void FrameBufferSDL2::queryHardware(vector<GUI::Size>& displays,
                                     VariantList& renderers)
 {
   // First get the maximum windowed desktop resolution
@@ -93,12 +92,12 @@ void FrameBufferSDL2::queryHardware(Common::Array<GUI::Size>& displays,
   // For now, supported render types are hardcoded; eventually, SDL may
   // provide a method to query this
 #if defined(BSPF_WINDOWS)
-  renderers.push_back("Direct3D", "direct3d");
+  VarList::push_back(renderers, "Direct3D", "direct3d");
 #endif
-  renderers.push_back("OpenGL", "opengl");
-  renderers.push_back("OpenGLES2", "opengles2");
-  renderers.push_back("OpenGLES", "opengles");
-  renderers.push_back("Software", "software");
+  VarList::push_back(renderers, "OpenGL", "opengl");
+  VarList::push_back(renderers, "OpenGLES2", "opengles2");
+  VarList::push_back(renderers, "OpenGLES", "opengles");
+  VarList::push_back(renderers, "Software", "software");
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -123,7 +122,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode,
     SDL_RenderPresent(myRenderer);
     SDL_RenderClear(myRenderer);
     SDL_DestroyRenderer(myRenderer);
-    myRenderer = NULL;
+    myRenderer = nullptr;
   }
 
   Int32 displayIndex = mode.fsIndex;
@@ -162,7 +161,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode,
     if((uInt32)w != mode.screen.w || (uInt32)h != mode.screen.h)
     {
       SDL_DestroyWindow(myWindow);
-      myWindow = NULL;
+      myWindow = nullptr;
     }
   }
   if(myWindow)
@@ -186,7 +185,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode,
   {
     myWindow = SDL_CreateWindow(title.c_str(), pos, pos,
                                 mode.screen.w, mode.screen.h, flags);
-    if(myWindow == NULL)
+    if(myWindow == nullptr)
     {
       string msg = "ERROR: Unable to open SDL window: " + string(SDL_GetError());
       myOSystem.logMessage(msg, 0);
@@ -202,7 +201,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode,
   if(video != "")
     SDL_SetHint(SDL_HINT_RENDER_DRIVER, video.c_str());
   myRenderer = SDL_CreateRenderer(myWindow, -1, renderFlags);
-  if(myRenderer == NULL)
+  if(myRenderer == nullptr)
   {
     string msg = "ERROR: Unable to create SDL renderer: " + string(SDL_GetError());
     myOSystem.logMessage(msg, 0);
@@ -210,12 +209,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode,
   }
   SDL_RendererInfo renderinfo;
   if(SDL_GetRendererInfo(myRenderer, &renderinfo) >= 0)
-  {
     myOSystem.settings().setValue("video", renderinfo.name);
-    // For now, accelerated renderers imply double buffering
-    // Eventually, SDL may be updated to query this from the render backend
-    myDblBufferedFlag = renderinfo.flags & SDL_RENDERER_ACCELERATED;
-  }
 
   return true;
 }
@@ -283,15 +277,15 @@ void FrameBufferSDL2::postFrameUpdate()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBufferSDL2::setWindowIcon()
 {
-#if defined(BSPF_WINDOWS) // Currently only needed for Windows
-  #include "stella.xpm"   // The Stella icon
+#ifndef BSPF_MAC_OSX     // Currently not needed for OSX
+  #include "stella.xpm"  // The Stella icon
 
   // Set the window icon
   uInt32 w, h, ncols, nbytes;
   uInt32 rgba[256], icon[32 * 32];
   uInt8  mask[32][4];
 
-  sscanf(stella_icon[0], "%u %u %u %u", &w, &h, &ncols, &nbytes);
+  sscanf(stella_icon[0], "%2u %2u %2u %2u", &w, &h, &ncols, &nbytes);
   if((w != 32) || (h != 32) || (ncols > 255) || (nbytes > 1))
   {
     myOSystem.logMessage("ERROR: Couldn't load the application icon.", 0);
@@ -300,7 +294,7 @@ void FrameBufferSDL2::setWindowIcon()
 
   for(uInt32 i = 0; i < ncols; i++)
   {
-    unsigned char code;
+    uInt8 code;
     char color[32];
     uInt32 col;
 
@@ -342,10 +336,10 @@ void FrameBufferSDL2::setWindowIcon()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FBSurface* FrameBufferSDL2::createSurface(uInt32 w, uInt32 h,
+unique_ptr<FBSurface> FrameBufferSDL2::createSurface(uInt32 w, uInt32 h,
                                           const uInt32* data) const
 {
-  return new FBSurfaceSDL2((FrameBufferSDL2&)*this, w, h, data);
+  return make_ptr<FBSurfaceSDL2>((FrameBufferSDL2&)*this, w, h, data);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
