@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: NTSCFilter.cxx 2889 2014-05-12 23:34:25Z stephena $
+// $Id: NTSCFilter.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "TIASurface.hxx"
@@ -30,11 +30,6 @@ NTSCFilter::NTSCFilter()
 {
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-NTSCFilter::~NTSCFilter()
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void NTSCFilter::setTIAPalette(const TIASurface& tiaSurface, const uInt32* palette)
 {
@@ -220,7 +215,7 @@ void NTSCFilter::saveConfig(Settings& settings) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void NTSCFilter::getAdjustables(Adjustable& adjustable, Preset preset)
+void NTSCFilter::getAdjustables(Adjustable& adjustable, Preset preset) const
 {
   switch(preset)
   {
