@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartF4SCWidget.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: CartF4SCWidget.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "CartF4SC.hxx"
@@ -49,14 +49,14 @@ CartridgeF4SCWidget::CartridgeF4SCWidget(
       ypos = addBaseInformation(size, "Atari", info.str(), 15) + myLineHeight;
 
   VariantList items;
-  items.push_back("0 ($FF4)");
-  items.push_back("1 ($FF5)");
-  items.push_back("2 ($FF6)");
-  items.push_back("3 ($FF7)");
-  items.push_back("4 ($FF8)");
-  items.push_back("5 ($FF9)");
-  items.push_back("6 ($FFA)");
-  items.push_back("7 ($FFB)");
+  VarList::push_back(items, "0 ($FF4)");
+  VarList::push_back(items, "1 ($FF5)");
+  VarList::push_back(items, "2 ($FF6)");
+  VarList::push_back(items, "3 ($FF7)");
+  VarList::push_back(items, "4 ($FF8)");
+  VarList::push_back(items, "5 ($FF9)");
+  VarList::push_back(items, "6 ($FFA)");
+  VarList::push_back(items, "7 ($FFB)");
   myBank =
     new PopUpWidget(boss, _font, xpos, ypos-2, _font.getStringWidth("0 ($FFx) "),
                     myLineHeight, items, "Set bank: ",
@@ -65,6 +65,17 @@ CartridgeF4SCWidget::CartridgeF4SCWidget(
   addFocusWidget(myBank);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void CartridgeF4SCWidget::saveOldState()
+{
+  myOldState.internalram.clear();
+  
+  for(uInt32 i = 0; i < this->internalRamSize();i++)
+  {
+    myOldState.internalram.push_back(myCart.myRAM[i]);
+  }
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeF4SCWidget::loadConfig()
 {
@@ -99,3 +110,62 @@ string CartridgeF4SCWidget::bankState()
 
   return buf.str();
 }
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+uInt32 CartridgeF4SCWidget::internalRamSize() 
+{
+  return 128;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+uInt32 CartridgeF4SCWidget::internalRamRPort(int start)
+{
+  return 0xF080 + start;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+string CartridgeF4SCWidget::internalRamDescription() 
+{
+  ostringstream desc;
+  desc << "$F000 - $F07F used for Write Access\n"
+       << "$F080 - $F0FF used for Read Access";
+  
+  return desc.str();
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+const ByteArray& CartridgeF4SCWidget::internalRamOld(int start, int count)
+{
+  myRamOld.clear();
+  for(int i = 0; i < count; i++)
+    myRamOld.push_back(myOldState.internalram[start + i]);
+  return myRamOld;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+const ByteArray& CartridgeF4SCWidget::internalRamCurrent(int start, int count)
+{
+  myRamCurrent.clear();
+  for(int i = 0; i < count; i++)
+    myRamCurrent.push_back(myCart.myRAM[start + i]);
+  return myRamCurrent;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void CartridgeF4SCWidget::internalRamSetValue(int addr, uInt8 value)
+{
+  myCart.myRAM[addr] = value;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+uInt8 CartridgeF4SCWidget::internalRamGetValue(int addr)
+{
+  return myCart.myRAM[addr];
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+string CartridgeF4SCWidget::internalRamLabel(int addr) 
+{
+  CartDebug& dbg = instance().debugger().cartDebug();
+  return dbg.getLabel(addr + 0xF080, false);
+}
