@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartF4Widget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: CartF4Widget.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "CartF4.hxx"
@@ -47,14 +47,14 @@ CartridgeF4Widget::CartridgeF4Widget(
       ypos = addBaseInformation(size, "Atari", info.str(), 15) + myLineHeight;
 
   VariantList items;
-  items.push_back("0 ($FF4)");
-  items.push_back("1 ($FF5)");
-  items.push_back("2 ($FF6)");
-  items.push_back("3 ($FF7)");
-  items.push_back("4 ($FF8)");
-  items.push_back("5 ($FF9)");
-  items.push_back("6 ($FFA)");
-  items.push_back("7 ($FFB)");
+  VarList::push_back(items, "0 ($FF4)");
+  VarList::push_back(items, "1 ($FF5)");
+  VarList::push_back(items, "2 ($FF6)");
+  VarList::push_back(items, "3 ($FF7)");
+  VarList::push_back(items, "4 ($FF8)");
+  VarList::push_back(items, "5 ($FF9)");
+  VarList::push_back(items, "6 ($FFA)");
+  VarList::push_back(items, "7 ($FFB)");
   myBank =
     new PopUpWidget(boss, _font, xpos, ypos-2, _font.getStringWidth("0 ($FFx) "),
                     myLineHeight, items, "Set bank: ",
