@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartF8Widget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: CartF8Widget.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "CartF8.hxx"
@@ -47,8 +47,8 @@ CartridgeF8Widget::CartridgeF8Widget(
       ypos = addBaseInformation(size, "Atari", info.str()) + myLineHeight;
 
   VariantList items;
-  items.push_back("0 ($FF8)");
-  items.push_back("1 ($FF9)");
+  VarList::push_back(items, "0 ($FF8)");
+  VarList::push_back(items, "1 ($FF9)");
   myBank =
     new PopUpWidget(boss, _font, xpos, ypos-2, _font.getStringWidth("0 ($FFx) "),
                     myLineHeight, items, "Set bank: ",
