@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartFAWidget.cxx 2936 2014-06-29 18:37:55Z stephena $
+// $Id: CartFAWidget.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "CartFA.hxx"
@@ -49,9 +49,9 @@ CartridgeFAWidget::CartridgeFAWidget(
       ypos = addBaseInformation(size, "CBS", info.str()) + myLineHeight;
 
   VariantList items;
-  items.push_back("0 ($FF8)");
-  items.push_back("1 ($FF9)");
-  items.push_back("2 ($FFA)");
+  VarList::push_back(items, "0 ($FF8)");
+  VarList::push_back(items, "1 ($FF9)");
+  VarList::push_back(items, "2 ($FFA)");
   myBank =
     new PopUpWidget(boss, _font, xpos, ypos-2, _font.getStringWidth("0 ($FFx) "),
                     myLineHeight, items, "Set bank: ",
