@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartSBWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: CartSBWidget.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "CartSB.hxx"
@@ -49,7 +49,7 @@ CartridgeSBWidget::CartridgeSBWidget(
 
     bank << dec << setw(2) << setfill(' ') << i << " ($" << Common::Base::HEX2
          << spot << ")";
-    items.push_back(bank.str());
+    VarList::push_back(items, bank.str());
     bank.str("");
   }
 
