@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ColorWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: ColorWidget.cxx 3156 2015-03-21 20:00:00Z stephena $
 //============================================================================
 
 #include "bspf.hxx"
@@ -46,7 +46,7 @@ ColorWidget::~ColorWidget()
 void ColorWidget::setColor(int color)
 {
   _color = color;
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
