@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: PromptWidget.cxx 2934 2014-06-21 20:51:08Z stephena $
+// $Id: PromptWidget.cxx 3156 2015-03-21 20:00:00Z stephena $
 //============================================================================
 
 #include <iostream>
@@ -28,7 +28,6 @@
 #include "Debugger.hxx"
 #include "DebuggerDialog.hxx"
 #include "DebuggerParser.hxx"
-#include "StringList.hxx"
 
 #include "PromptWidget.hxx"
 #include "CartDebug.hxx"
@@ -42,8 +41,7 @@ PromptWidget::PromptWidget(GuiObject* boss, const GUI::Font& font,
     CommandSender(boss),
     _makeDirty(false),
     _firstTime(true),
-    _exitedEarly(false),
-    _lastModPressed(KBDM_NONE)
+    _exitedEarly(false)
 {
   _flags = WIDGET_ENABLED | WIDGET_CLEARBG | WIDGET_RETAIN_FOCUS |
            WIDGET_WANTS_TAB | WIDGET_WANTS_RAWDATA;
@@ -88,19 +86,21 @@ void PromptWidget::drawWidget(bool hilite)
   int start = _scrollLine - _linesPerPage + 1;
   int y = _y + 2;
 
-  for (int line = 0; line < _linesPerPage; line++)
+  for (int line = 0; line < _linesPerPage; ++line)
   {
     int x = _x + 1;
-    for (int column = 0; column < _lineWidth; column++) {
+    for (int column = 0; column < _lineWidth; ++column) {
       int c = buffer((start + line) * _lineWidth + column);
 
-      if(c & (1 << 17)) { // inverse video flag
+      if(c & (1 << 17))  // inverse video flag
+      {
         fgcolor = _bgcolor;
         bgcolor = (c & 0x1ffff) >> 8;
         s.fillRect(x, y, _kConsoleCharWidth, _kConsoleCharHeight, bgcolor);
-      } else {
-        fgcolor = c >> 8;
       }
+      else
+        fgcolor = c >> 8;
+
       s.drawChar(_font, c & 0x7f, x, y, fgcolor);
       x += _kConsoleCharWidth;
     }
@@ -140,28 +140,21 @@ void PromptWidget::printPrompt()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool PromptWidget::handleText(char text)
 {
-  // FIXME - convert this class to inherit from EditableWidget
-  // Huge hack to test if ALT key was pressed in the last handleKeyDown call
-  if(instance().eventHandler().kbdAlt(_lastModPressed))
-    return false;
-
-  for(int i = _promptEndPos - 1; i >= _currentPos; i--)
-    buffer(i + 1) = buffer(i);
-  _promptEndPos++;
-  putchar(text);
-  scrollToCurrent();
-
+  if(text >= 0)
+  {
+    // FIXME - convert this class to inherit from EditableWidget
+    for(int i = _promptEndPos - 1; i >= _currentPos; i--)
+      buffer(i + 1) = buffer(i);
+    _promptEndPos++;
+    putcharIntern(text);
+    scrollToCurrent();
+  }
   return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool PromptWidget::handleKeyDown(StellaKey key, StellaMod mod)
 {
-  // Ignore all alt-mod keys
-  _lastModPressed = mod;
-  if(instance().eventHandler().kbdAlt(mod))
-    return true;
-
   bool handled = true;
   bool dirty = false;
   
@@ -216,7 +209,7 @@ bool PromptWidget::handleKeyDown(StellaKey key, StellaMod mod)
 
       scrollToCurrent();
       int len = _promptEndPos - _promptStartPos;
-      if(len > 256) len = 256;
+      if(len > 255) len = 255;
 
       int lastDelimPos = -1;
       char delimiter = '\0';
@@ -439,9 +432,7 @@ bool PromptWidget::handleKeyDown(StellaKey key, StellaMod mod)
 
   // Take care of changes made above
   if(dirty)
-  {
-    setDirty(); draw();
-  }
+    setDirty();
 
   // There are times when we want the prompt and scrollbar to be marked
   // as dirty *after* they've been drawn above.  One such occurrence is
@@ -460,6 +451,7 @@ bool PromptWidget::handleKeyDown(StellaKey key, StellaMod mod)
   return handled;
 }
 
+#if 0
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::insertIntoPrompt(const char* str)
 {
@@ -473,6 +465,7 @@ void PromptWidget::insertIntoPrompt(const char* str)
     putcharIntern(str[j]);
   }
 }
+#endif
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::handleCommand(CommandSender* sender, int cmd,
@@ -485,7 +478,7 @@ void PromptWidget::handleCommand(CommandSender* sender, int cmd,
       if (newPos != _scrollLine)
       {
         _scrollLine = newPos;
-        setDirty(); draw();
+        setDirty();
       }
       break;
   }
@@ -560,9 +553,7 @@ void PromptWidget::specialKeys(StellaKey key)
   }
 
   if(handled)
-  {
-    setDirty(); draw();
-  }
+    setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -653,10 +644,13 @@ void PromptWidget::addToHistory(const char *str)
     _historySize++;
 }
 
+#if 0 // FIXME
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int PromptWidget::compareHistory(const char *histLine) {
+int PromptWidget::compareHistory(const char *histLine)
+{
   return 1;
 }
+#endif
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::historyScroll(int direction)
@@ -713,7 +707,7 @@ void PromptWidget::historyScroll(int direction)
   // Ensure once more the caret is visible (in case of very long history entries)
   scrollToCurrent();
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -758,7 +752,7 @@ void PromptWidget::updateScrollBuffer()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int PromptWidget::printf(const char *format, ...)
+int PromptWidget::printf(const char* format, ...)
 {
   va_list argptr;
 
@@ -769,7 +763,7 @@ int PromptWidget::printf(const char *format, ...)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int PromptWidget::vprintf(const char *format, va_list argptr)
+int PromptWidget::vprintf(const char* format, va_list argptr)
 {
   char buf[2048];
   int count = BSPF_vsnprintf(buf, sizeof(buf), format, argptr);
@@ -778,13 +772,6 @@ int PromptWidget::vprintf(const char *format, va_list argptr)
   return count;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PromptWidget::putchar(int c)
-{
-  putcharIntern(c);
-  setDirty(); draw();
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::putcharIntern(int c)
 {
@@ -796,14 +783,14 @@ void PromptWidget::putcharIntern(int c)
                       // OverlayColor contains 256 of them
     _textcolor = (c & 0x7f) << 1;
   }
-  else if(c < 0x1e) { // first actual character is large dash
+  else if(c && c < 0x1e) { // first actual character is large dash
     // More colors (the regular GUI ones)
     _textcolor = c + 0x100;
   }
   else if(c == 0x7f) { // toggle inverse video (DEL char)
     _inverse = !_inverse;
   }
-  else
+  else if(isprint(c))
   {
     buffer(_currentPos) = c | (_textcolor << 8) | (_inverse << 17);
     _currentPos++;
@@ -813,14 +800,14 @@ void PromptWidget::putcharIntern(int c)
       updateScrollBuffer();
     }
   }
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::print(const string& str)
 {
-  const char* c = str.c_str();
-  while(*c)
-    putcharIntern(*c++);
+  for(char c: str)
+    putcharIntern(c);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -896,9 +883,8 @@ string PromptWidget::getCompletionPrefix(const StringList& completions, string p
   // of the strings we're dealing with, it's probably not worth it
   for(;;)
   {
-    for(uInt32 i = 0; i < completions.size(); ++i)
+    for(const auto& s: completions)
     {
-      const string& s = completions[i];
       if(s.length() < prefix.length())
         return prefix;  // current prefix is the best we're going to get
       else if(!BSPF_startsWithIgnoreCase(s, prefix))
