@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: RomListWidget.cxx 2992 2014-09-06 00:33:17Z stephena $
+// $Id: RomListWidget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //============================================================================
 
 #include "bspf.hxx"
@@ -31,7 +31,6 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
                              const GUI::Font& nfont,
                              int x, int y, int w, int h)
   : EditableWidget(boss, nfont, x, y, 16, 16),
-    myMenu(NULL),
     _rows(0),
     _cols(0),
     _currentPos(0),
@@ -58,7 +57,7 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   myScrollBar->setTarget(this);
 
   // Add settings menu
-  myMenu = new RomListSettings(this, lfont);
+  myMenu = make_ptr<RomListSettings>(this, lfont);
 
   // Take advantage of a wide debugger window when possible
   const int fontWidth = lfont.getMaxCharWidth(),
@@ -77,7 +76,7 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   _rows = h / _fontHeight;
 
   // Create a CheckboxWidget for each row in the list
-  CheckboxWidget* t;
+  CheckboxWidget* t = nullptr;
   for(int i = 0; i < _rows; ++i)
   {
     t = new CheckboxWidget(boss, lfont, _x + 2, ypos, "", kCheckActionCmd);
@@ -89,12 +88,38 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
 
     myCheckList.push_back(t);
   }
+
+  // Add filtering
+  EditableWidget::TextFilter f = [&](char c)
+  {
+    switch(_base)
+    {
+      case Common::Base::F_16:
+      case Common::Base::F_16_1:
+      case Common::Base::F_16_2:
+      case Common::Base::F_16_4:
+      case Common::Base::F_16_8:
+        return (c >= '0' && c <= '9') || (c >= 'a' && c <= 'f') || c == ' ';
+
+      case Common::Base::F_2:
+      case Common::Base::F_2_8:
+      case Common::Base::F_2_16:
+        return c == '0' || c == '1' || c == ' ';
+
+      case Common::Base::F_10:
+        return (c >= '0' && c <= '9') || c == ' ';
+
+      case Common::Base::F_DEFAULT:
+        return false;
+    }
+    return false;
+  };
+  setTextFilter(f);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 RomListWidget::~RomListWidget()
 {
-  delete myMenu;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -110,12 +135,10 @@ void RomListWidget::setList(const CartDebug::Disassembly& disasm,
 
   // Then turn off any extras
   if((int)myDisasm->list.size() < _rows)
-    for(int i = myDisasm->list.size(); i < _rows; ++i)
+    for(int i = (int)myDisasm->list.size(); i < _rows; ++i)
       myCheckList[i]->clearFlags(WIDGET_ENABLED);
 
   recalc();
-
-  setDirty(); draw();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -157,15 +180,6 @@ void RomListWidget::setHighlighted(int item)
   }
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string& RomListWidget::getText() const
-{
-  if(_selectedItem < -1 || _selectedItem >= (int)myDisasm->list.size())
-    return EmptyString;
-  else
-    return _editString;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int RomListWidget::findItem(int x, int y) const
 {
@@ -175,7 +189,7 @@ int RomListWidget::findItem(int x, int y) const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void RomListWidget::recalc()
 {
-  int size = myDisasm->list.size();
+  int size = (int)myDisasm->list.size();
 
   if (_currentPos >= size)
     _currentPos = size - 1;
@@ -187,11 +201,13 @@ void RomListWidget::recalc()
 
   _editMode = false;
 
-  myScrollBar->_numEntries     = myDisasm->list.size();
+  myScrollBar->_numEntries     = (int)myDisasm->list.size();
   myScrollBar->_entriesPerPage = _rows;
 
   // Reset to normal data entry
   abortEditMode();
+
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -212,12 +228,12 @@ void RomListWidget::scrollToCurrent(int item)
   if (_currentPos < 0 || _rows > (int)myDisasm->list.size())
     _currentPos = 0;
   else if (_currentPos + _rows > (int)myDisasm->list.size())
-    _currentPos = myDisasm->list.size() - _rows;
+    _currentPos = (int)myDisasm->list.size() - _rows;
 
   myScrollBar->_currentPos = _currentPos;
   myScrollBar->recalc();
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -247,7 +263,7 @@ void RomListWidget::handleMouseDown(int x, int y, int button, int clickCount)
       if (_editMode)
         abortEditMode();
       _selectedItem = newSelectedItem;
-      setDirty(); draw();
+      setDirty();
     }
   }
 }
@@ -260,7 +276,7 @@ void RomListWidget::handleMouseUp(int x, int y, int button, int clickCount)
   if (clickCount == 2 && (_selectedItem == findItem(x, y)))
   {
     // Start edit mode
-    if(_editable && !_editMode)
+    if(isEditable() && !_editMode)
       startEditMode();
   }
 }
@@ -347,7 +363,7 @@ bool RomListWidget::handleEvent(Event::Type e)
     case Event::UISelect:
       if (_selectedItem >= 0)
       {
-        if (_editable)
+        if (isEditable())
           startEditMode();
       }
       break;
@@ -371,7 +387,7 @@ bool RomListWidget::handleEvent(Event::Type e)
     case Event::UIPgDown:
       _selectedItem += _rows - 1;
       if (_selectedItem >= (int)myDisasm->list.size())
-        _selectedItem = myDisasm->list.size() - 1;
+        _selectedItem = (int)myDisasm->list.size() - 1;
       break;
 
     case Event::UIHome:
@@ -379,7 +395,7 @@ bool RomListWidget::handleEvent(Event::Type e)
       break;
 
     case Event::UIEnd:
-      _selectedItem = myDisasm->list.size() - 1;
+      _selectedItem = (int)myDisasm->list.size() - 1;
       break;
 
     default:
@@ -411,7 +427,7 @@ void RomListWidget::handleCommand(CommandSender* sender, int cmd, int data, int
       if (_currentPos != (int)data)
       {
         _currentPos = data;
-        setDirty(); draw();
+        setDirty();
       }
       break;
 
@@ -433,10 +449,9 @@ void RomListWidget::lostFocusWidget()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void RomListWidget::drawWidget(bool hilite)
 {
-//cerr << "RomListWidget::drawWidget\n";
   FBSurface& s = _boss->dialog().surface();
   const CartDebug::DisassemblyList& dlist = myDisasm->list;
-  int i, pos, xpos, ypos, len = dlist.size();
+  int i, pos, xpos, ypos, len = (int)dlist.size();
 
   const GUI::Rect& r = getEditRect();
   const GUI::Rect& l = getLineRect();
@@ -508,7 +523,7 @@ void RomListWidget::drawWidget(bool hilite)
         if (_selectedItem == pos && _editMode)
         {
           adjustOffset();
-          s.drawString(_font, _editString, _x + r.x(), ypos, r.width(), kTextColor,
+          s.drawString(_font, editString(), _x + r.x(), ypos, r.width(), kTextColor,
                        kTextAlignLeft, -_editScrollOffset, false);
 
           drawCaret();
@@ -555,44 +570,10 @@ GUI::Rect RomListWidget::getEditRect() const
   return r;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool RomListWidget::tryInsertChar(char c, int pos)
-{
-  // Not sure how efficient this is, or should we even care?
-  bool insert = false;
-  c = tolower(c);
-  switch(_base)
-  {
-    case Common::Base::F_16:
-    case Common::Base::F_16_1:
-    case Common::Base::F_16_2:
-    case Common::Base::F_16_4:
-    case Common::Base::F_16_8:
-      insert = (c >= '0' && c <= '9') || (c >= 'a' && c <= 'f') || c == ' ';
-      break;
-    case Common::Base::F_2:
-    case Common::Base::F_2_8:
-    case Common::Base::F_2_16:
-      insert = c == '0' || c == '1' || c == ' ';
-      break;
-    case Common::Base::F_10:
-      if((c >= '0' && c <= '9') || c == ' ')
-        insert = true;
-      break;
-    case Common::Base::F_DEFAULT:
-      break;
-  }
-
-  if(insert)
-    _editString.insert(pos, 1, c);
-
-  return insert;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void RomListWidget::startEditMode()
 {
-  if (_editable && !_editMode && _selectedItem >= 0)
+  if (isEditable() && !_editMode && _selectedItem >= 0)
   {
     // Does this line represent an editable area?
     if(myDisasm->list[_selectedItem].bytes == "")
