@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: TogglePixelWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: TogglePixelWidget.cxx 3156 2015-03-21 20:00:00Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -29,7 +29,8 @@ TogglePixelWidget::TogglePixelWidget(GuiObject* boss, const GUI::Font& font,
                                      int x, int y, int cols, int rows)
   : ToggleWidget(boss, font, x, y, cols, rows),
     _pixelColor(0),
-    _backgroundColor(kDlgColor)
+    _backgroundColor(kDlgColor),
+    _swapBits(false)
 {
   _rowHeight = _colWidth = font.getLineHeight();
 
@@ -53,13 +54,13 @@ void TogglePixelWidget::setState(const BoolArray& state)
   _stateList.clear();
   _stateList = state;
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TogglePixelWidget::setIntState(int value, bool swap)
 {
-  unsigned int size = _rows * _cols;
+  uInt32 size = _rows * _cols;
   _swapBits = swap;
 
   // Create array of required size
@@ -75,7 +76,7 @@ void TogglePixelWidget::setIntState(int value, bool swap)
   //
   //   Swap on means reverse of swap off!  Sorry if this is
   //   confusing.
-  for(unsigned int i = 0; i < size; ++i)
+  for(uInt32 i = 0; i < size; ++i)
   {
     bool bitIsSet = value & (1 << i);
     if(_swapBits)
@@ -91,9 +92,9 @@ void TogglePixelWidget::setIntState(int value, bool swap)
 int TogglePixelWidget::getIntState()
 {
   // Construct int based on current state and swap
-  unsigned int value = 0, size = _stateList.size();
+  uInt32 value = 0, size = (int)_stateList.size();
 
-  for(unsigned int i = 0; i < size; ++i)
+  for(uInt32 i = 0; i < size; ++i)
   {
     if(_stateList[i])
     {
