@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ToggleWidget.cxx 2913 2014-06-10 16:43:35Z stephena $
+// $Id: ToggleWidget.cxx 3156 2015-03-21 20:00:00Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -30,6 +30,8 @@ ToggleWidget::ToggleWidget(GuiObject* boss, const GUI::Font& font,
     _cols(cols),
     _currentRow(0),
     _currentCol(0),
+    _rowHeight(0),
+    _colWidth(0),
     _selectedItem(0),
     _editable(true)
 {
@@ -59,7 +61,7 @@ void ToggleWidget::handleMouseDown(int x, int y, int button, int clickCount)
     _selectedItem = newSelectedItem;
     _currentRow = _selectedItem / _cols;
     _currentCol = _selectedItem - (_currentRow * _cols);
-    setDirty(); draw();
+    setDirty();
   }
 }
 
@@ -76,7 +78,7 @@ void ToggleWidget::handleMouseUp(int x, int y, int button, int clickCount)
     _stateList[_selectedItem] = !_stateList[_selectedItem];
     _changedList[_selectedItem] = !_changedList[_selectedItem];
     sendCommand(ToggleWidget::kItemDataChangedCmd, _selectedItem, _id);
-    setDirty(); draw();
+    setDirty();
   }
 }
 
@@ -193,7 +195,7 @@ bool ToggleWidget::handleKeyDown(StellaKey key, StellaMod mod)
       sendCommand(ToggleWidget::kItemDataChangedCmd, _selectedItem, _id);
     }
 
-    setDirty(); draw();
+    setDirty();
   }
 
   return handled;
@@ -209,7 +211,7 @@ void ToggleWidget::handleCommand(CommandSender* sender, int cmd,
       if (_selectedItem != (int)data)
       {
         _selectedItem = data;
-        setDirty(); draw();
+        setDirty();
       }
       break;
   }
