@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: AtariVox.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: AtariVox.cxx 3142 2015-01-24 16:28:06Z stephena $
 //============================================================================
 
 #include "MT24LC256.hxx"
@@ -28,7 +28,6 @@ AtariVox::AtariVox(Jack jack, const Event& event, const System& system,
                    const string& eepromfile)
   : Controller(jack, event, system, Controller::AtariVox),
     mySerialPort((SerialPort&)port),
-    myEEPROM(NULL),
     myShiftCount(0),
     myShiftRegister(0),
     myLastDataWriteCycle(0)
@@ -38,7 +37,7 @@ AtariVox::AtariVox(Jack jack, const Event& event, const System& system,
   else
     myAboutString = " (invalid serial port \'" + portname + "\')";
 
-  myEEPROM = new MT24LC256(eepromfile, system);
+  myEEPROM = make_ptr<MT24LC256>(eepromfile, system);
 
   myDigitalPinState[One] = myDigitalPinState[Two] =
   myDigitalPinState[Three] = myDigitalPinState[Four] = true;
@@ -49,8 +48,6 @@ AtariVox::AtariVox(Jack jack, const Event& event, const System& system,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 AtariVox::~AtariVox()
 {
-  mySerialPort.closePort();
-  delete myEEPROM;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
