@@ -8,18 +8,18 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartCM.cxx 2963 2014-07-28 13:40:37Z stephena $
+// $Id: CartCM.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
-#include <cassert>
 #include <cstring>
 
+#include "CompuMate.hxx"
 #include "System.hxx"
 #include "M6532.hxx"
 #include "CartCM.hxx"
@@ -61,10 +61,6 @@ void CartridgeCM::reset()
 void CartridgeCM::install(System& system)
 {
   mySystem = &system;
-  uInt16 mask = mySystem->pageMask();
-
-  // Make sure the system we're being installed in has a page size that'll work
-  assert((0x1000 & mask) == 0);
 
   // Mirror all access in RIOT; by doing so we're taking responsibility
   // for that address space in peek and poke below.
@@ -95,14 +91,21 @@ bool CartridgeCM::poke(uInt16 address, uInt8 value)
     {
       mySWCHA = value;
       bank(mySWCHA & 0x3);
-      if(value & 0x20) myColumn = 0;
-      if(value & 0x40) myColumn = (myColumn + 1) % 10;
+      uInt8& column = myCompuMate->myColumn;
+      if(value & 0x20) column = 0;
+      if(value & 0x40) column = (column + 1) % 10;
     }
     mySystem->m6532().poke(address, value);
   }
   return myBankChanged;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+uInt8 CartridgeCM::column() const
+{
+  return myCompuMate->myColumn;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool CartridgeCM::bank(uInt16 bank)
 {
@@ -111,7 +114,6 @@ bool CartridgeCM::bank(uInt16 bank)
   // Remember what bank we're in
   myCurrentBank = bank;
   uInt16 offset = myCurrentBank << 12;
-  uInt16 shift = mySystem->pageShift();
 
   // Although this scheme contains four 4K ROM banks and one 2K RAM bank,
   // it's easier to think of things in terms of 2K slices, as follows:
@@ -124,15 +126,17 @@ bool CartridgeCM::bank(uInt16 bank)
   System::PageAccess access(this, System::PA_READ);
 
   // Lower 2K (always ROM)
-  for(uInt32 address = 0x1000; address < 0x1800; address += (1 << shift))
+  for(uInt32 address = 0x1000; address < 0x1800;
+      address += (1 << System::PAGE_SHIFT))
   {
     access.directPeekBase = &myImage[offset + (address & 0x0FFF)];
     access.codeAccessBase = &myCodeAccessBase[offset + (address & 0x0FFF)];
-    mySystem->setPageAccess(address >> shift, access);
+    mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
   }
 
   // Upper 2K (RAM or ROM)
-  for(uInt32 address = 0x1800; address < 0x2000; address += (1 << shift))
+  for(uInt32 address = 0x1800; address < 0x2000;
+      address += (1 << System::PAGE_SHIFT))
   {
     access.type = System::PA_READWRITE;
 
@@ -152,7 +156,7 @@ bool CartridgeCM::bank(uInt16 bank)
     else
       access.directPokeBase = 0;
 
-    mySystem->setPageAccess(address >> shift, access);
+    mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
   }
 
   return myBankChanged = true;
@@ -200,7 +204,7 @@ bool CartridgeCM::save(Serializer& out) const
     out.putString(name());
     out.putShort(myCurrentBank);
     out.putByte(mySWCHA);
-    out.putByte(myColumn);
+    out.putByte(myCompuMate->myColumn);
     out.putByteArray(myRAM, 2048);
   }
   catch(...)
@@ -222,7 +226,7 @@ bool CartridgeCM::load(Serializer& in)
 
     myCurrentBank = in.getShort();
     mySWCHA = in.getByte();
-    myColumn = in.getByte();
+    myCompuMate->myColumn = in.getByte();
     in.getByteArray(myRAM, 2048);
   }
   catch(...)
