@@ -8,16 +8,15 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartDASH.cxx 2968 2014-07-31 17:05:21Z stephena $
+// $Id: CartDASH.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
-#include <cassert>
 #include <cstring>
 
 #include "System.hxx"
@@ -25,9 +24,11 @@
 #include "CartDASH.hxx"
 
 //  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CartridgeDASH::CartridgeDASH(const uInt8* image, uInt32 size, const Settings& settings) :
-    Cartridge(settings), mySize(size) {
-
+CartridgeDASH::CartridgeDASH(const uInt8* image, uInt32 size, const Settings& settings)
+  : Cartridge(settings),
+    mySize(size),
+    myImage(nullptr)
+{
   // Allocate array for the ROM image
   myImage = new uInt8[mySize];
 
@@ -41,7 +42,8 @@ CartridgeDASH::CartridgeDASH(const uInt8* image, uInt32 size, const Settings& se
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CartridgeDASH::~CartridgeDASH() {
+CartridgeDASH::~CartridgeDASH()
+{
   delete[] myImage;
 }
 
@@ -74,20 +76,14 @@ void CartridgeDASH::install(System& system) {
 
   mySystem = &system;
 
-  uInt16 shift = mySystem->pageShift();
-  uInt16 mask = mySystem->pageMask();
-
-  // Make sure the system we're being installed in has a page size that'll work
-  assert((0x1800 & mask) == 0);
-
   System::PageAccess access(this, System::PA_READWRITE);
 
   // Set the page accessing methods for the hot spots (for 100% emulation
   // we need to chain any accesses below 0x40 to the TIA. Our poke() method
   // does this via mySystem->tiaPoke(...), at least until we come up with a
   // cleaner way to do it).
-  for (uInt32 i = 0x00; i < 0x40; i += (1 << shift))
-    mySystem->setPageAccess(i >> shift, access);
+  for (uInt32 i = 0x00; i < 0x40; i += (1 << System::PAGE_SHIFT))
+    mySystem->setPageAccess(i >> System::PAGE_SHIFT, access);
 
   // Initialise bank values for all ROM/RAM access
   // This is used to reverse-lookup from address to bank location
@@ -182,8 +178,6 @@ bool CartridgeDASH::bankRAM(uInt8 bank) {
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeDASH::bankRAMSlot(uInt16 bank) {
 
-  uInt16 shift = mySystem->pageShift();
-
   uInt16 bankNumber = (bank >> BANK_BITS) & 3;  // which bank # we are switching TO (BITS D6,D7) to 512 byte block
   uInt16 currentBank = bank & BIT_BANK_MASK;    // Wrap around/restrict to valid range
   bool upper = bank & BITMASK_LOWERUPPER;       // is this the read or write port
@@ -208,13 +202,13 @@ void CartridgeDASH::bankRAMSlot(uInt16 bank) {
   uInt32 start = 0x1000 + (bankNumber << RAM_BANK_TO_POWER) + (upper ? RAM_WRITE_OFFSET : 0);
   uInt32 end = start + RAM_BANK_SIZE - 1;
 
-  for (uInt32 address = start; address <= end; address += (1 << shift)) {
+  for (uInt32 address = start; address <= end; address += (1 << System::PAGE_SHIFT)) {
     if(upper)
       access.directPokeBase = &myRAM[startCurrentBank + (address & (RAM_BANK_SIZE - 1))];
     else
       access.directPeekBase = &myRAM[startCurrentBank + (address & (RAM_BANK_SIZE - 1))];
     access.codeAccessBase = &myCodeAccessBase[mySize + startCurrentBank + (address & (RAM_BANK_SIZE - 1))];
-    mySystem->setPageAccess(address >> shift, access);
+    mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
   }
 }
 
@@ -240,8 +234,6 @@ bool CartridgeDASH::bankROM(uInt8 bank) {
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeDASH::bankROMSlot(uInt16 bank) {
 
-  uInt16 shift = mySystem->pageShift();
-
   uInt16 bankNumber = (bank >> BANK_BITS) & 3;    // which bank # we are switching TO (BITS D6,D7)
   uInt16 currentBank = bank & BIT_BANK_MASK;      // Wrap around/restrict to valid range
   bool upper = bank & BITMASK_LOWERUPPER;         // is this the lower or upper 512b
@@ -256,18 +248,16 @@ void CartridgeDASH::bankROMSlot(uInt16 bank) {
   uInt32 start = 0x1000 + (bankNumber << ROM_BANK_TO_POWER) + (upper ? ROM_BANK_SIZE / 2 : 0);
   uInt32 end = start + ROM_BANK_SIZE / 2 - 1;
 
-  for (uInt32 address = start; address <= end; address += (1 << shift)) {
+  for (uInt32 address = start; address <= end; address += (1 << System::PAGE_SHIFT)) {
     access.directPeekBase = &myImage[startCurrentBank + (address & (ROM_BANK_SIZE - 1))];
     access.codeAccessBase = &myCodeAccessBase[startCurrentBank + (address & (ROM_BANK_SIZE - 1))];
-    mySystem->setPageAccess(address >> shift, access);
+    mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CartridgeDASH::initializeBankState() {
 
-  const uInt16& shift = mySystem->pageShift();
-
   // Switch in each 512b slot
   for (uInt32 b = 0; b < 8; b++) {
     if (bankInUse[b] == BANK_UNDEFINED) {
@@ -276,8 +266,8 @@ void CartridgeDASH::initializeBankState() {
       System::PageAccess access(this, System::PA_READ);
       uInt32 start = 0x1000 + (b << RAM_BANK_TO_POWER);
       uInt32 end = start + RAM_BANK_SIZE - 1;
-      for (uInt32 address = start; address <= end; address += (1 << shift))
-        mySystem->setPageAccess(address >> shift, access);
+      for (uInt32 address = start; address <= end; address += (1 << System::PAGE_SHIFT))
+        mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
 
     }
     else if (bankInUse[b] & BITMASK_ROMRAM)
