@@ -8,16 +8,15 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartMDM.cxx 2985 2014-09-01 14:56:06Z stephena $
+// $Id: CartMDM.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
-#include <cassert>
 #include <cstring>
 
 #include "System.hxx"
@@ -26,7 +25,7 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeMDM::CartridgeMDM(const uInt8* image, uInt32 size, const Settings& settings)
   : Cartridge(settings),
-    myImage(NULL),
+    myImage(nullptr),
     mySize(size),
     myBankingDisabled(false)
 {
@@ -44,7 +43,7 @@ CartridgeMDM::CartridgeMDM(const uInt8* image, uInt32 size, const Settings& sett
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeMDM::~CartridgeMDM()
 {
-  delete[] myImage;  myImage = NULL;
+  delete[] myImage;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -58,27 +57,22 @@ void CartridgeMDM::reset()
 void CartridgeMDM::install(System& system)
 {
   mySystem = &system;
-  uInt16 shift = mySystem->pageShift();
-  uInt16 mask = mySystem->pageMask();
-
-  // Make sure the system we're being installed in has a page size that'll work
-  assert((0x1000 & mask) == 0);
 
   // Get the page accessing methods for the hot spots since they overlap
   // areas within the TIA we'll need to forward requests to the TIA
-  myHotSpotPageAccess[0] = mySystem->getPageAccess(0x0800 >> shift);
-  myHotSpotPageAccess[1] = mySystem->getPageAccess(0x0900 >> shift);
-  myHotSpotPageAccess[2] = mySystem->getPageAccess(0x0A00 >> shift);
-  myHotSpotPageAccess[3] = mySystem->getPageAccess(0x0B00 >> shift);
-  myHotSpotPageAccess[4] = mySystem->getPageAccess(0x0C00 >> shift);
-  myHotSpotPageAccess[5] = mySystem->getPageAccess(0x0D00 >> shift);
-  myHotSpotPageAccess[6] = mySystem->getPageAccess(0x0E00 >> shift);
-  myHotSpotPageAccess[7] = mySystem->getPageAccess(0x0F00 >> shift);
+  myHotSpotPageAccess[0] = mySystem->getPageAccess(0x0800 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[1] = mySystem->getPageAccess(0x0900 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[2] = mySystem->getPageAccess(0x0A00 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[3] = mySystem->getPageAccess(0x0B00 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[4] = mySystem->getPageAccess(0x0C00 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[5] = mySystem->getPageAccess(0x0D00 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[6] = mySystem->getPageAccess(0x0E00 >> System::PAGE_SHIFT);
+  myHotSpotPageAccess[7] = mySystem->getPageAccess(0x0F00 >> System::PAGE_SHIFT);
 
   // Set the page accessing methods for the hot spots
-  System::PageAccess access(this, System::PA_READ);
-  for(uInt32 i = 0x0800; i < 0x0FFF; i += (1 << shift))
-    mySystem->setPageAccess(i >> shift, access);
+  System::PageAccess access(this, System::PA_READWRITE);
+  for(uInt32 i = 0x0800; i < 0x0FFF; i += (1 << System::PAGE_SHIFT))
+    mySystem->setPageAccess(i >> System::PAGE_SHIFT, access);
 
   // Install pages for bank 0
   bank(myStartBank);
@@ -89,7 +83,8 @@ uInt8 CartridgeMDM::peek(uInt16 address)
 {
   // Because of the way we've set up accessing above, we can only
   // get here when the addresses are from 0x800 - 0xFFF
-  bank(address & 0x0FF);
+  if(address < 0xC00)
+    bank(address & 0x0FF);
 
   int hotspot = ((address & 0x0F00) >> 8) - 8;
   return myHotSpotPageAccess[hotspot].device->peek(address);
@@ -98,12 +93,13 @@ uInt8 CartridgeMDM::peek(uInt16 address)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool CartridgeMDM::poke(uInt16 address, uInt8 value)
 {
-  // Currently, writing to the hotspots is disabled, so we don't need to
-  // worry about bankswitching
-  // However, all possible addresses can appear here, and we only care
+  // All possible addresses can appear here, but we only care
   // about those below $1000
   if(!(address & 0x1000))
   {
+    if(address < 0xC00)
+      bank(address & 0x0FF);
+
     int hotspot = ((address & 0x0F00) >> 8) - 8;
     myHotSpotPageAccess[hotspot].device->poke(address, value);
   }
@@ -120,17 +116,17 @@ bool CartridgeMDM::bank(uInt16 bank)
   // Wrap around to a valid bank number if necessary
   myCurrentBank = bank % bankCount();
   uInt32 offset = myCurrentBank << 12;
-  uInt16 shift = mySystem->pageShift();
 
   // Setup the page access methods for the current bank
   System::PageAccess access(this, System::PA_READ);
 
   // Map ROM image into the system
-  for(uInt32 address = 0x1000; address < 0x2000; address += (1 << shift))
+  for(uInt32 address = 0x1000; address < 0x2000;
+      address += (1 << System::PAGE_SHIFT))
   {
     access.directPeekBase = &myImage[offset + (address & 0x0FFF)];
     access.codeAccessBase = &myCodeAccessBase[offset + (address & 0x0FFF)];
-    mySystem->setPageAccess(address >> shift, access);
+    mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
   }
 
   // Accesses above bank 127 disable further bankswitching; we're only
