@@ -8,32 +8,29 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CompuMate.cxx 2872 2014-03-09 19:22:04Z stephena $
+// $Id: CompuMate.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "Control.hxx"
-#include "System.hxx"
 #include "StellaKeys.hxx"
 #include "CompuMate.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CompuMate::CompuMate(CartridgeCM& cart, const Event& event,
+CompuMate::CompuMate(const Console& console, const Event& event,
                      const System& system)
-  : myCart(cart),
-    myEvent(event),
-    mySystem(system),
-    myLeftController(0),
-    myRightController(0),
-    myCycleAtLastUpdate(0)
+  : myConsole(console),
+    myEvent(event)
 {
-  myLeftController = new CMControl(*this, Controller::Left, event, system);
-  myRightController = new CMControl(*this, Controller::Right, event, system);
+  // These controller pointers will be retrieved by the Console, which will
+  // also take ownership of them
+  myLeftController  = make_ptr<CMControl>(*this, Controller::Left, event, system);
+  myRightController = make_ptr<CMControl>(*this, Controller::Right, event, system);
 
   myLeftController->myAnalogPinValue[Controller::Nine] = Controller::maximumResistance;
   myLeftController->myAnalogPinValue[Controller::Five] = Controller::minimumResistance;
@@ -58,19 +55,9 @@ void CompuMate::enableKeyHandling(bool enable)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void CompuMate::update()
 {
-  uInt32 cycle = mySystem.cycles();
-
-  // Only perform update once for both ports in the same cycle
-  if(myCycleAtLastUpdate != cycle)
-  {
-    myCycleAtLastUpdate = cycle;
-    return;
-  }
-  myCycleAtLastUpdate = cycle;
-
   // Handle SWCHA changes - the following comes almost directly from z26
-  Controller& lp = *myLeftController;
-  Controller& rp = *myRightController;
+  Controller& lp = myConsole.leftController();
+  Controller& rp = myConsole.rightController();
 
   lp.myAnalogPinValue[Controller::Nine] = Controller::maximumResistance;
   lp.myAnalogPinValue[Controller::Five] = Controller::minimumResistance;
@@ -86,7 +73,8 @@ void CompuMate::update()
 
   rp.myDigitalPinState[Controller::Three] = true;
   rp.myDigitalPinState[Controller::Four] = true;
-  switch(myCart.column())
+
+  switch(myColumn)
   {
     case 0:
       if (myKeyTable[KBDK_7]) lp.myDigitalPinState[Controller::Six] = false;
