@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Console.cxx 2912 2014-06-09 16:35:19Z stephena $
+// $Id: Console.cxx 3148 2015-03-15 17:36:46Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -66,15 +66,10 @@
 #include "Console.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Console::Console(OSystem& osystem, Cartridge& cart, const Properties& props)
+Console::Console(OSystem& osystem, Cartridge* cart, const Properties& props)
   : myOSystem(osystem),
-    myCart(cart),
     myEvent(osystem.eventHandler().event()),
     myProperties(props),
-    myTIA(0),
-    mySwitches(0),
-    mySystem(0),
-    myCMHandler(0),
     myDisplayFormat(""),  // Unknown TV format @ start
     myFramerate(0.0),     // Unknown framerate @ start
     myCurrentFormat(0),   // Unknown format @ start
@@ -83,31 +78,25 @@ Console::Console(OSystem& osystem, Cartridge& cart, const Properties& props)
   // Load user-defined palette for this ROM
   loadUserPalette();
 
-  // Create switches for the console
-  mySwitches = new Switches(myEvent, myProperties);
+  // Create subsystems for the console
+  my6502 = make_ptr<M6502>(myOSystem.settings());
+  myRiot = make_ptr<M6532>(*this, myOSystem.settings());
+  myTIA  = make_ptr<TIA>(*this, myOSystem.sound(), myOSystem.settings());
+  myCart = unique_ptr<Cartridge>(cart);
+  mySwitches = make_ptr<Switches>(myEvent, myProperties);
 
   // Construct the system and components
-  mySystem = new System();
+  mySystem = make_ptr<System>(osystem, *my6502, *myRiot, *myTIA, *myCart);
 
   // The real controllers for this console will be added later
   // For now, we just add dummy joystick controllers, since autodetection
   // runs the emulation for a while, and this may interfere with 'smart'
   // controllers such as the AVox and SaveKey
-  // Note that the controllers must be added directly after the system
-  // has been created, and before any other device is added
-  // (particularly the M6532)
-  myControllers[0] = new Joystick(Controller::Left, myEvent, *mySystem);
-  myControllers[1] = new Joystick(Controller::Right, myEvent, *mySystem);
+  myLeftControl  = make_ptr<Joystick>(Controller::Left, myEvent, *mySystem);
+  myRightControl = make_ptr<Joystick>(Controller::Right, myEvent, *mySystem);
 
-  M6502* m6502 = new M6502(1, myOSystem.settings());
-
-  myRiot = new M6532(*this, myOSystem.settings());
-  myTIA  = new TIA(*this, myOSystem.sound(), myOSystem.settings());
-
-  mySystem->attach(m6502);
-  mySystem->attach(myRiot);
-  mySystem->attach(myTIA);
-  mySystem->attach(&myCart);
+  // We can only initialize after all the devices/components have been created
+  mySystem->initialize();
 
   // Auto-detect NTSC/PAL mode if it's requested
   string autodetected = "";
@@ -166,21 +155,16 @@ Console::Console(OSystem& osystem, Cartridge& cart, const Properties& props)
   // Finally, add remaining info about the console
   myConsoleInfo.CartName   = myProperties.get(Cartridge_Name);
   myConsoleInfo.CartMD5    = myProperties.get(Cartridge_MD5);
-  myConsoleInfo.Control0   = myControllers[0]->about();
-  myConsoleInfo.Control1   = myControllers[1]->about();
-  myConsoleInfo.BankSwitch = myCart.about();
+  myConsoleInfo.Control0   = myLeftControl->about();
+  myConsoleInfo.Control1   = myRightControl->about();
+  myConsoleInfo.BankSwitch = myCart->about();
 
-  myCart.setRomName(myConsoleInfo.CartName);
+  myCart->setRomName(myConsoleInfo.CartName);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Console::~Console()
 {
-  delete mySystem;
-  delete mySwitches;
-  delete myCMHandler;
-  delete myControllers[0];
-  delete myControllers[1];
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -193,7 +177,7 @@ bool Console::save(Serializer& out) const
       return false;
 
     // Now save the console controllers and switches
-    if(!(myControllers[0]->save(out) && myControllers[1]->save(out) &&
+    if(!(myLeftControl->save(out) && myRightControl->save(out) &&
          mySwitches->save(out)))
       return false;
   }
@@ -216,7 +200,7 @@ bool Console::load(Serializer& in)
       return false;
 
     // Then load the console controllers and switches
-    if(!(myControllers[0]->load(in) && myControllers[1]->load(in) &&
+    if(!(myLeftControl->load(in) && myRightControl->load(in) &&
          mySwitches->load(in)))
       return false;
   }
@@ -475,7 +459,7 @@ void Console::initializeAudio()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Console::fry() const
 {
-  for (int ZPmem=0; ZPmem<0x100; ZPmem += rand() % 4)
+  for(int ZPmem = 0; ZPmem < 0x100; ZPmem += rand() % 4)
     mySystem->poke(ZPmem, mySystem->peek(ZPmem) & (uInt8)rand() % 256);
 }
 
@@ -507,7 +491,6 @@ void Console::changeYStart(int direction)
 
   myTIA->setYStart(ystart);
   myTIA->frameReset();
-  myOSystem.frameBuffer().refresh();
 
   ostringstream val;
   val << ystart;
@@ -595,9 +578,6 @@ void Console::setTIAProperties()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Console::setControllers(const string& rommd5)
 {
-  delete myControllers[0];
-  delete myControllers[1];
-
   // Setup the controllers based on properties
   const string& left  = myProperties.get(Controller_Left);
   const string& right = myProperties.get(Controller_Right);
@@ -606,23 +586,21 @@ void Console::setControllers(const string& rommd5)
   // creates them for us, and also that they must be used in both ports
   if(left == "COMPUMATE" || right == "COMPUMATE")
   {
-    delete myCMHandler;
-    myCMHandler = new CompuMate(*((CartridgeCM*)&myCart), myEvent, *mySystem);
-    myControllers[0] = myCMHandler->leftController();
-    myControllers[1] = myCMHandler->rightController();
+    myCMHandler = make_shared<CompuMate>(*this, myEvent, *mySystem);
+
+    // A somewhat ugly bit of code that casts to CartridgeCM to
+    // add the CompuMate, and then back again for the actual
+    // Cartridge
+    unique_ptr<CartridgeCM> cartcm(static_cast<CartridgeCM*>(myCart.release()));
+    cartcm->setCompuMate(myCMHandler);
+    myCart = std::move(cartcm);
+
+    myLeftControl  = std::move(myCMHandler->leftController());
+    myRightControl = std::move(myCMHandler->rightController());
     return;
   }
 
-  // Swap the ports if necessary
-  int leftPort, rightPort;
-  if(myProperties.get(Console_SwapPorts) == "NO")
-  {
-    leftPort = 0; rightPort = 1;
-  }
-  else
-  {
-    leftPort = 1; rightPort = 0;
-  }
+  unique_ptr<Controller> leftC, rightC;
 
   // Also check if we should swap the paddles plugged into a jack
   bool swapPaddles = myProperties.get(Controller_SwapPaddles) == "YES";
@@ -630,15 +608,15 @@ void Console::setControllers(const string& rommd5)
   // Construct left controller
   if(left == "BOOSTERGRIP")
   {
-    myControllers[leftPort] = new BoosterGrip(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<BoosterGrip>(Controller::Left, myEvent, *mySystem);
   }
   else if(left == "DRIVING")
   {
-    myControllers[leftPort] = new Driving(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<Driving>(Controller::Left, myEvent, *mySystem);
   }
   else if((left == "KEYBOARD") || (left == "KEYPAD"))
   {
-    myControllers[leftPort] = new Keyboard(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<Keyboard>(Controller::Left, myEvent, *mySystem);
   }
   else if(BSPF_startsWithIgnoreCase(left, "PADDLES"))
   {
@@ -649,50 +627,49 @@ void Console::setControllers(const string& rommd5)
       swapDir = true;
     else if(left == "PADDLES_IAXDR")
       swapAxis = swapDir = true;
-    myControllers[leftPort] =
-      new Paddles(Controller::Left, myEvent, *mySystem,
-                  swapPaddles, swapAxis, swapDir);
+    leftC = make_ptr<Paddles>(Controller::Left, myEvent, *mySystem,
+                              swapPaddles, swapAxis, swapDir);
   }
   else if(left == "TRACKBALL22")
   {
-    myControllers[leftPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                            Controller::TrackBall22);
+    leftC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                Controller::TrackBall22);
   }
   else if(left == "TRACKBALL80")
   {
-    myControllers[leftPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                            Controller::TrackBall80);
+    leftC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                Controller::TrackBall80);
   }
   else if(left == "AMIGAMOUSE")
   {
-    myControllers[leftPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                            Controller::AmigaMouse);
+    leftC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                Controller::AmigaMouse);
   }
   else if(left == "GENESIS")
   {
-    myControllers[leftPort] = new Genesis(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<Genesis>(Controller::Left, myEvent, *mySystem);
   }
   else if(left == "MINDLINK")
   {
-    myControllers[leftPort] = new MindLink(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<MindLink>(Controller::Left, myEvent, *mySystem);
   }
   else
   {
-    myControllers[leftPort] = new Joystick(Controller::Left, myEvent, *mySystem);
+    leftC = make_ptr<Joystick>(Controller::Left, myEvent, *mySystem);
   }
  
   // Construct right controller
   if(right == "BOOSTERGRIP")
   {
-    myControllers[rightPort] = new BoosterGrip(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<BoosterGrip>(Controller::Right, myEvent, *mySystem);
   }
   else if(right == "DRIVING")
   {
-    myControllers[rightPort] = new Driving(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<Driving>(Controller::Right, myEvent, *mySystem);
   }
   else if((right == "KEYBOARD") || (right == "KEYPAD"))
   {
-    myControllers[rightPort] = new Keyboard(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<Keyboard>(Controller::Right, myEvent, *mySystem);
   }
   else if(BSPF_startsWithIgnoreCase(right, "PADDLES"))
   {
@@ -703,53 +680,64 @@ void Console::setControllers(const string& rommd5)
       swapDir = true;
     else if(right == "PADDLES_IAXDR")
       swapAxis = swapDir = true;
-    myControllers[rightPort] =
-      new Paddles(Controller::Right, myEvent, *mySystem,
-                  swapPaddles, swapAxis, swapDir);
+    rightC = make_ptr<Paddles>(Controller::Right, myEvent, *mySystem,
+                               swapPaddles, swapAxis, swapDir);
   }
   else if(right == "TRACKBALL22")
   {
-    myControllers[rightPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                             Controller::TrackBall22);
+    rightC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                 Controller::TrackBall22);
   }
   else if(right == "TRACKBALL80")
   {
-    myControllers[rightPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                             Controller::TrackBall80);
+    rightC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                 Controller::TrackBall80);
   }
   else if(right == "AMIGAMOUSE")
   {
-    myControllers[rightPort] = new TrackBall(Controller::Left, myEvent, *mySystem,
-                                             Controller::AmigaMouse);
+    rightC = make_ptr<TrackBall>(Controller::Left, myEvent, *mySystem,
+                                 Controller::AmigaMouse);
   }
   else if(right == "ATARIVOX")
   {
     const string& nvramfile = myOSystem.nvramDir() + "atarivox_eeprom.dat";
-    myControllers[rightPort] = new AtariVox(Controller::Right, myEvent,
+    rightC = make_ptr<AtariVox>(Controller::Right, myEvent,
                    *mySystem, myOSystem.serialPort(),
                    myOSystem.settings().getString("avoxport"), nvramfile);
   }
   else if(right == "SAVEKEY")
   {
     const string& nvramfile = myOSystem.nvramDir() + "savekey_eeprom.dat";
-    myControllers[rightPort] = new SaveKey(Controller::Right, myEvent, *mySystem,
-                                           nvramfile);
+    rightC = make_ptr<SaveKey>(Controller::Right, myEvent, *mySystem,
+                               nvramfile);
   }
   else if(right == "GENESIS")
   {
-    myControllers[rightPort] = new Genesis(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<Genesis>(Controller::Right, myEvent, *mySystem);
   }
   else if(right == "KIDVID")
   {
-    myControllers[rightPort] = new KidVid(Controller::Right, myEvent, *mySystem, rommd5);
+    rightC = make_ptr<KidVid>(Controller::Right, myEvent, *mySystem, rommd5);
   }
   else if(right == "MINDLINK")
   {
-    myControllers[rightPort] = new MindLink(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<MindLink>(Controller::Right, myEvent, *mySystem);
   }
   else
   {
-    myControllers[rightPort] = new Joystick(Controller::Right, myEvent, *mySystem);
+    rightC = make_ptr<Joystick>(Controller::Right, myEvent, *mySystem);
+  }
+
+  // Swap the ports if necessary
+  if(myProperties.get(Console_SwapPorts) == "NO")
+  {
+    myLeftControl  = std::move(leftC);
+    myRightControl = std::move(rightC);
+  }
+  else
+  {
+    myLeftControl  = std::move(rightC);
+    myRightControl = std::move(leftC);
   }
 }
 
@@ -907,11 +895,11 @@ void Console::toggleFixedColors() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Console::addDebugger()
+void Console::attachDebugger(Debugger& dbg)
 {
 #ifdef DEBUGGER_SUPPORT
-  myOSystem.createDebugger(*this);
-  mySystem->m6502().attach(myOSystem.debugger());
+//  myOSystem.createDebugger(*this);
+  mySystem->m6502().attach(dbg);
 #endif
 }
 
@@ -1147,20 +1135,3 @@ uInt32 Console::ourUserPALPalette[256]   = { 0 }; // filled from external file
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt32 Console::ourUserSECAMPalette[256] = { 0 }; // filled from external file
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Console::Console(const Console& console)
-  : myOSystem(console.myOSystem),
-    myCart(console.myCart),
-    myEvent(console.myEvent)
-{
-  assert(false);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Console& Console::operator = (const Console&)
-{
-  assert(false);
-
-  return *this;
-}
