@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: FrameBuffer.cxx 2989 2014-09-03 13:27:33Z stephena $
+// $Id: FrameBuffer.cxx 3148 2015-03-15 17:36:46Z stephena $
 //============================================================================
 
 #include <algorithm>
@@ -49,28 +49,15 @@
 FrameBuffer::FrameBuffer(OSystem& osystem)
   : myOSystem(osystem),
     myInitializedCount(0),
-    myPausedCount(0),
-    myTIASurface(NULL)
+    myPausedCount(0)
 {
-  myMsg.surface = myStatsMsg.surface = NULL;
+  myMsg.surface = myStatsMsg.surface = nullptr;
   myMsg.enabled = myStatsMsg.enabled = false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FrameBuffer::~FrameBuffer(void)
+FrameBuffer::~FrameBuffer()
 {
-  delete myFont;
-  delete myInfoFont;
-  delete mySmallFont;
-  delete myLauncherFont;
-  delete myTIASurface;
-
-  // Free all allocated surfaces
-  while(!mySurfaceList.empty())
-  {
-    delete (*mySurfaceList.begin()).second;
-    mySurfaceList.erase(mySurfaceList.begin());
-  }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -83,7 +70,7 @@ bool FrameBuffer::initialize()
   // Check the 'maxres' setting, which is an undocumented developer feature
   // that specifies the desktop size (not normally set)
   const GUI::Size& s = myOSystem.settings().getSize("maxres");
-  if(s.w > 0 && s.h > 0)
+  if(s.valid())
   {
     query_w = s.w;
     query_h = s.h;
@@ -107,15 +94,15 @@ bool FrameBuffer::initialize()
   // This font is used in a variety of situations when a really small
   // font is needed; we let the specific widget/dialog decide when to
   // use it
-  mySmallFont = new GUI::Font(GUI::stellaDesc);
+  mySmallFont = make_ptr<GUI::Font>(GUI::stellaDesc);
 
   // The general font used in all UI elements
   // This is determined by the size of the framebuffer
-  myFont = new GUI::Font(smallScreen ? GUI::stellaDesc : GUI::stellaMediumDesc);
+  myFont = make_ptr<GUI::Font>(smallScreen ? GUI::stellaDesc : GUI::stellaMediumDesc);
 
   // The info font used in all UI elements
   // This is determined by the size of the framebuffer
-  myInfoFont = new GUI::Font(smallScreen ? GUI::stellaDesc : GUI::consoleDesc);
+  myInfoFont = make_ptr<GUI::Font>(smallScreen ? GUI::stellaDesc : GUI::consoleDesc);
 
   // The font used by the ROM launcher
   // Normally, this is configurable by the user, except in the case of
@@ -124,14 +111,14 @@ bool FrameBuffer::initialize()
   {    
     const string& lf = myOSystem.settings().getString("launcherfont");
     if(lf == "small")
-      myLauncherFont = new GUI::Font(GUI::consoleDesc);
+      myLauncherFont = make_ptr<GUI::Font>(GUI::consoleDesc);
     else if(lf == "medium")
-      myLauncherFont = new GUI::Font(GUI::stellaMediumDesc);
+      myLauncherFont = make_ptr<GUI::Font>(GUI::stellaMediumDesc);
     else
-      myLauncherFont = new GUI::Font(GUI::stellaLargeDesc);
+      myLauncherFont = make_ptr<GUI::Font>(GUI::stellaLargeDesc);
   }
   else
-    myLauncherFont = new GUI::Font(GUI::stellaDesc);
+    myLauncherFont = make_ptr<GUI::Font>(GUI::stellaDesc);
 
   // Determine possible TIA windowed zoom levels
   uInt32 maxZoom = maxWindowSizeForScreen((uInt32)kTIAMinW, (uInt32)kTIAMinH,
@@ -143,7 +130,7 @@ bool FrameBuffer::initialize()
   {
     ostringstream desc;
     desc << "Zoom " << zoom << "x";
-    myTIAZoomLevels.push_back(desc.str(), zoom);
+    VarList::push_back(myTIAZoomLevels, desc.str(), zoom);
   }
 
   // Set palette for GUI (upper area of array, doesn't change during execution)
@@ -160,7 +147,7 @@ bool FrameBuffer::initialize()
   FBSurface::setPalette(myPalette);
 
   // Create a TIA surface; we need it for rendering TIA images
-  myTIASurface = new TIASurface(myOSystem);
+  myTIASurface = make_ptr<TIASurface>(myOSystem);
 
   return true;
 }
@@ -241,19 +228,14 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
   myStatsMsg.w = infoFont().getMaxCharWidth() * 24 + 2;
   myStatsMsg.h = (infoFont().getFontHeight() + 2) * 2;
 
-  if(myStatsMsg.surface == NULL)
-  {
-    uInt32 surfaceID = allocateSurface(myStatsMsg.w, myStatsMsg.h);
-    myStatsMsg.surface = surface(surfaceID);
-  }
-  if(myMsg.surface == NULL)
-  {
-    uInt32 surfaceID = allocateSurface((uInt32)kFBMinW, font().getFontHeight()+10);
-    myMsg.surface = surface(surfaceID);
-  }
+  if(!myStatsMsg.surface)
+    myStatsMsg.surface = allocateSurface(myStatsMsg.w, myStatsMsg.h);
+
+  if(!myMsg.surface)
+    myMsg.surface = allocateSurface((uInt32)kFBMinW, font().getFontHeight()+10);
 
   // Print initial usage message, but only print it later if the status has changed
-  if (myInitializedCount == 1)
+  if(myInitializedCount == 1)
   {
     myOSystem.logMessage(about(), 1);
   }
@@ -273,6 +255,8 @@ void FrameBuffer::update()
   // Determine which mode we are in (from the EventHandler)
   // Take care of S_EMULATE mode here, otherwise let the GUI
   // figure out what to draw
+
+  invalidate();
   switch(myOSystem.eventHandler().state())
   {
     case EventHandler::S_EMULATE:
@@ -312,6 +296,8 @@ void FrameBuffer::update()
 
     case EventHandler::S_PAUSE:
     {
+      drawTIA();
+
       // Show a pause message every 5 seconds
       if(myPausedCount++ >= 7*myOSystem.frameRate())
       {
@@ -323,26 +309,28 @@ void FrameBuffer::update()
 
     case EventHandler::S_MENU:
     {
-      myOSystem.menu().draw();
+      drawTIA();
+      myOSystem.menu().draw(true);
       break;  // S_MENU
     }
 
     case EventHandler::S_CMDMENU:
     {
-      myOSystem.commandMenu().draw();
+      drawTIA();
+      myOSystem.commandMenu().draw(true);
       break;  // S_CMDMENU
     }
 
     case EventHandler::S_LAUNCHER:
     {
-      myOSystem.launcher().draw();
+      myOSystem.launcher().draw(true);
       break;  // S_LAUNCHER
     }
 
 #ifdef DEBUGGER_SUPPORT
     case EventHandler::S_DEBUGGER:
     {
-      myOSystem.debugger().draw();
+      myOSystem.debugger().draw(true);
       break;  // S_DEBUGGER
     }
 #endif
@@ -367,10 +355,6 @@ void FrameBuffer::showMessage(const string& message, MessagePosition position,
   if(!(force || myOSystem.settings().getBool("uimessages")))
     return;
 
-  // Erase old messages on the screen
-  if(myMsg.counter > 0)
-    refresh();
-
   // Precompute the message coordinates
   myMsg.text    = message;
   myMsg.counter = uInt32(myOSystem.frameRate()) << 1; // Show message for 2 seconds
@@ -395,7 +379,6 @@ void FrameBuffer::showFrameStats(bool enable)
 {
   myOSystem.settings().setValue("stats", enable);
   myStatsMsg.enabled = enable;
-  refresh();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -414,8 +397,7 @@ void FrameBuffer::enableMessages(bool enable)
     // Erase old messages on the screen
     myMsg.enabled = false;
     myMsg.counter = 0;
-
-    refresh();
+    update();  // Force update immediately
   }
 }
 
@@ -476,20 +458,16 @@ inline void FrameBuffer::drawMessage()
   myMsg.surface->box(0, 0, myMsg.w, myMsg.h, kColor, kShadowColor);
   myMsg.surface->drawString(font(), myMsg.text, 4, 4,
                             myMsg.w, myMsg.color, kTextAlignLeft);
-  myMsg.counter--;
 
   // Either erase the entire message (when time is reached),
   // or show again this frame
-  if(myMsg.counter == 0)  // Force an immediate update
-  {
-    myMsg.enabled = false;
-    refresh();
-  }
-  else
+  if(myMsg.counter-- > 0)
   {
     myMsg.surface->setDirty();
     myMsg.surface->render();
   }
+  else
+    myMsg.enabled = false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -499,98 +477,13 @@ inline void FrameBuffer::drawTIA()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::refresh()
+shared_ptr<FBSurface> FrameBuffer::allocateSurface(int w, int h, const uInt32* data)
 {
-  // This method partly duplicates the behaviour in ::update()
-  // Here, however, make sure to redraw *all* surfaces applicable to the
-  // current EventHandler state
-  // We also check for double-buffered modes, and when present
-  // update both buffers accordingly
-  //
-  // This method is in essence a FULL refresh, putting all rendering
-  // buffers in a known, fully redrawn state
+  // Add new surface to the list
+  mySurfaceList.push_back(createSurface(w, h, data));
 
-  switch(myOSystem.eventHandler().state())
-  {
-    case EventHandler::S_EMULATE:
-    case EventHandler::S_PAUSE:
-      invalidate();
-      drawTIA();
-      break;
-
-    case EventHandler::S_MENU:
-      invalidate();
-      drawTIA();
-      myOSystem.menu().draw(true);
-      if(isDoubleBuffered())
-      {
-        postFrameUpdate();
-        invalidate();
-        drawTIA();
-        myOSystem.menu().draw(true);
-      }
-      break;
-
-    case EventHandler::S_CMDMENU:
-      invalidate();
-      drawTIA();
-      myOSystem.commandMenu().draw(true);
-      if(isDoubleBuffered())
-      {
-        postFrameUpdate();
-        invalidate();
-        drawTIA();
-        myOSystem.commandMenu().draw(true);
-      }
-      break;
-
-    case EventHandler::S_LAUNCHER:
-      invalidate();
-      myOSystem.launcher().draw(true);
-      if(isDoubleBuffered())
-      {
-        postFrameUpdate();
-        invalidate();
-        myOSystem.launcher().draw(true);
-      }
-      break;
-
-  #ifdef DEBUGGER_SUPPORT
-    case EventHandler::S_DEBUGGER:
-      invalidate();
-      myOSystem.debugger().draw(true);
-      if(isDoubleBuffered())
-      {
-        postFrameUpdate();
-        invalidate();
-        myOSystem.debugger().draw(true);
-      }
-      break;
-  #endif
-
-    default:
-      break;
-  }
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 FrameBuffer::allocateSurface(int w, int h, const uInt32* data)
-{
-  // Create a new surface
-  FBSurface* surface = createSurface(w, h, data);
-
-  // Add it to the list
-  mySurfaceList.insert(make_pair((uInt32)mySurfaceList.size(), surface));
-
-  // Return a reference to it
-  return (uInt32)mySurfaceList.size() - 1;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FBSurface* FrameBuffer::surface(uInt32 id) const
-{
-  map<uInt32,FBSurface*>::const_iterator iter = mySurfaceList.find(id);
-  return iter != mySurfaceList.end() ? iter->second : NULL;
+  // And return a pointer to it (pointer should be treated read-only)
+  return mySurfaceList.at(mySurfaceList.size() - 1);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -602,11 +495,10 @@ void FrameBuffer::resetSurfaces()
   // Any derived FrameBuffer classes that call this method should be
   // aware of these restrictions, and act accordingly
 
-  map<uInt32,FBSurface*>::iterator iter;
-  for(iter = mySurfaceList.begin(); iter != mySurfaceList.end(); ++iter)
-    iter->second->free();
-  for(iter = mySurfaceList.begin(); iter != mySurfaceList.end(); ++iter)
-    iter->second->reload();
+  for(auto& s: mySurfaceList)
+    s->free();
+  for(auto& s: mySurfaceList)
+    s->reload();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -652,7 +544,6 @@ void FrameBuffer::setFullscreen(bool enable)
     myOSystem.settings().setValue("fullscreen", fullScreen());
     resetSurfaces();
     setCursorState();
-    refresh();
   }
 }
 
@@ -693,7 +584,6 @@ bool FrameBuffer::changeWindowedVidMode(int direction)
     resetSurfaces();
     showMessage(mode.description);
     myOSystem.settings().setValue("tia.zoom", mode.zoom);
-    refresh();
     return true;
   }
 #endif
@@ -721,7 +611,7 @@ void FrameBuffer::toggleGrabMouse()
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt32 FrameBuffer::maxWindowSizeForScreen(uInt32 baseWidth, uInt32 baseHeight,
-                    uInt32 screenWidth, uInt32 screenHeight)
+                    uInt32 screenWidth, uInt32 screenHeight) const
 {
   uInt32 multiplier = 1;
   for(;;)
@@ -743,9 +633,9 @@ void FrameBuffer::setAvailableVidModes(uInt32 baseWidth, uInt32 baseHeight)
 {
   myWindowedModeList.clear();
 
-  for(uInt32 i = 0; i < myFullscreenModeLists.size(); ++i)
-    myFullscreenModeLists[i].clear();
-  for(uInt32 i = myFullscreenModeLists.size(); i < myDisplays.size(); ++i)
+  for(auto& mode: myFullscreenModeLists)
+    mode.clear();
+  for(size_t i = myFullscreenModeLists.size(); i < myDisplays.size(); ++i)
     myFullscreenModeLists.push_back(VideoModeList());
 
   // Check if zooming is allowed for this state (currently only allowed
@@ -941,7 +831,7 @@ FrameBuffer::VideoModeList::~VideoModeList()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::VideoModeList::add(const VideoMode& mode)
 {
-  myModeList.push_back(mode);
+  myModeList.emplace_back(mode);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -951,22 +841,22 @@ void FrameBuffer::VideoModeList::clear()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool FrameBuffer::VideoModeList::isEmpty() const
+bool FrameBuffer::VideoModeList::empty() const
 {
-  return myModeList.isEmpty();
+  return myModeList.empty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt32 FrameBuffer::VideoModeList::size() const
 {
-  return myModeList.size();
+  return (uInt32)myModeList.size();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::VideoModeList::previous()
 {
   --myIdx;
-  if(myIdx < 0) myIdx = myModeList.size() - 1;
+  if(myIdx < 0) myIdx = (int)myModeList.size() - 1;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
