@@ -8,18 +8,15 @@
 // MM     MM 66  66 55  55 00  00 22
 // MM     MM  6666   5555   0000  222222
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: M6502.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: M6502.cxx 3144 2015-02-06 16:34:01Z stephena $
 //============================================================================
 
-//#define DEBUG_OUTPUT
-#define debugStream cout
-
 #ifdef DEBUGGER_SUPPORT
   #include "Debugger.hxx"
   #include "Expression.hxx"
@@ -43,17 +40,16 @@
   #define DISASM_NONE  0
 #endif
 #include "Settings.hxx"
+#include "Vec.hxx"
 
 #include "M6502.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-M6502::M6502(uInt32 systemCyclesPerProcessorCycle, const Settings& settings)
+M6502::M6502(const Settings& settings)
   : myExecutionStatus(0),
-    mySystem(0),
+    mySystem(nullptr),
     mySettings(settings),
-    mySystemCyclesPerProcessorCycle(systemCyclesPerProcessorCycle),
     myLastAccessWasRead(true),
-    myTotalInstructionCount(0),
     myNumberOfDistinctAccesses(0),
     myLastAddress(0),
     myLastPeekAddress(0),
@@ -65,35 +61,14 @@ M6502::M6502(uInt32 systemCyclesPerProcessorCycle, const Settings& settings)
     myDataAddressForPoke(0)
 {
 #ifdef DEBUGGER_SUPPORT
-  myDebugger    = NULL;
-  myBreakPoints = NULL;
-  myReadTraps   = NULL;
-  myWriteTraps  = NULL;
-
+  myDebugger = nullptr;
   myJustHitTrapFlag = false;
 #endif
-
-  // Compute the System Cycle table
-  for(uInt32 t = 0; t < 256; ++t)
-  {
-    myInstructionSystemCycleTable[t] = ourInstructionCycleTable[t] *
-        mySystemCyclesPerProcessorCycle;
-  }
-
-#ifdef DEBUG_OUTPUT
-debugStream << "( Fm  Ln Cyc Clk) ( P0  P1  M0  M1  BL)  "
-            << "flags   A  X  Y SP  Code           Disasm" << endl
-            << endl;
-#endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 M6502::~M6502()
 {
-#ifdef DEBUGGER_SUPPORT
-  myBreakConds.clear();
-  myBreakCondNames.clear();
-#endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -109,20 +84,18 @@ void M6502::reset()
   // Clear the execution status flags
   myExecutionStatus = 0;
 
-  // Set registers to default values
-  SP = 0xff;
-  if(mySettings.getBool("cpurandom"))
-  {
-    A = mySystem->randGenerator().next();
-    X = mySystem->randGenerator().next();
-    Y = mySystem->randGenerator().next();
-    PS(mySystem->randGenerator().next());
-  }
-  else
-  {
-    A = X = Y = 0;
-    PS(0x20);
-  }
+  // Set registers to random or default values
+  const string& cpurandom = mySettings.getString("cpurandom");
+  SP = BSPF_containsIgnoreCase(cpurandom, "S") ?
+          mySystem->randGenerator().next() : 0xff;
+  A  = BSPF_containsIgnoreCase(cpurandom, "A") ?
+          mySystem->randGenerator().next() : 0x00;
+  X  = BSPF_containsIgnoreCase(cpurandom, "X") ?
+          mySystem->randGenerator().next() : 0x00;
+  Y  = BSPF_containsIgnoreCase(cpurandom, "Y") ?
+          mySystem->randGenerator().next() : 0x00;
+  PS(BSPF_containsIgnoreCase(cpurandom, "P") ?
+          mySystem->randGenerator().next() : 0x20);
 
   // Reset access flag
   myLastAccessWasRead = true;
@@ -130,8 +103,6 @@ void M6502::reset()
   // Load PC from the reset vector
   PC = (uInt16)mySystem->peek(0xfffc) | ((uInt16)mySystem->peek(0xfffd) << 8);
 
-  myTotalInstructionCount = 0;
-
   myLastAddress = myLastPeekAddress = myLastPokeAddress = 0;
   myLastSrcAddressS = myLastSrcAddressA =
     myLastSrcAddressX = myLastSrcAddressY = -1;
@@ -149,17 +120,16 @@ inline uInt8 M6502::peek(uInt16 address, uInt8 flags)
     myLastAddress = address;
   }
   ////////////////////////////////////////////////
-  mySystem->incrementCycles(mySystemCyclesPerProcessorCycle);
+  mySystem->incrementCycles(SYSTEM_CYCLES_PER_CPU);
 
 #ifdef DEBUGGER_SUPPORT
-  if(myReadTraps != NULL && myReadTraps->isSet(address))
+  if(myReadTraps.isInitialized() && myReadTraps.isSet(address))
   {
     myJustHitTrapFlag = true;
     myHitTrapInfo.message = "RTrap: ";
     myHitTrapInfo.address = address;
   }
-//cerr << "addr = " << HEX4 << address << ", flags = " << Debugger::to_bin_8(flags) << endl;
-#endif
+#endif  // DEBUGGER_SUPPORT
 
   uInt8 result = mySystem->peek(address, flags);
   myLastAccessWasRead = true;
@@ -178,16 +148,16 @@ inline void M6502::poke(uInt16 address, uInt8 value)
     myLastAddress = address;
   }
   ////////////////////////////////////////////////
-  mySystem->incrementCycles(mySystemCyclesPerProcessorCycle);
+  mySystem->incrementCycles(SYSTEM_CYCLES_PER_CPU);
 
 #ifdef DEBUGGER_SUPPORT
-  if(myWriteTraps != NULL && myWriteTraps->isSet(address))
+  if(myWriteTraps.isInitialized() && myWriteTraps.isSet(address))
   {
     myJustHitTrapFlag = true;
     myHitTrapInfo.message = "WTrap: ";
     myHitTrapInfo.address = address;
   }
-#endif
+#endif  // DEBUGGER_SUPPORT
 
   mySystem->poke(address, value);
   myLastAccessWasRead = false;
@@ -215,14 +185,9 @@ bool M6502::execute(uInt32 number)
         }
       }
 
-      if(myBreakPoints != NULL)
-      {
-        if(myBreakPoints->isSet(PC))
-        {
-          if(myDebugger && myDebugger->start("BP: ", PC))
-            return true;
-        }
-      }
+      if(myBreakPoints.isInitialized() && myBreakPoints.isSet(PC))
+        if(myDebugger && myDebugger->start("BP: ", PC))
+          return true;
 
       int cond = evalCondBreaks();
       if(cond > -1)
@@ -231,7 +196,8 @@ bool M6502::execute(uInt32 number)
         if(myDebugger && myDebugger->start(buf))
           return true;
       }
-#endif
+#endif  // DEBUGGER_SUPPORT
+
       uInt16 operandAddress = 0, intermediateAddress = 0;
       uInt8 operand = 0;
 
@@ -241,23 +207,6 @@ bool M6502::execute(uInt32 number)
       // Fetch instruction at the program counter
       IR = peek(PC++, DISASM_CODE);  // This address represents a code section
 
-#ifdef DEBUG_OUTPUT
-      debugStream << ::hex << setw(2) << (int)A << " "
-                  << ::hex << setw(2) << (int)X << " "
-                  << ::hex << setw(2) << (int)Y << " "
-                  << ::hex << setw(2) << (int)SP << "  "
-                  << setw(4) << (PC-1) << ": "
-                  << setw(2) << (int)IR << "       "
-//      << "<" << ourAddressingModeTable[IR] << " ";
-//      debugStream << hex << setw(4) << operandAddress << " ";
-//                  << setw(3) << ourInstructionMnemonicTable[IR]
-
-//      debugStream << "PS=" << ::hex << setw(2) << (int)PS() << " ";
-
-//      debugStream << "Cyc=" << dec << mySystem->cycles();
-                  << endl;
-#endif
-
       // Call code to execute the instruction
       switch(IR)
       {
@@ -268,7 +217,6 @@ bool M6502::execute(uInt32 number)
           // Oops, illegal instruction executed so set fatal error flag
           myExecutionStatus |= FatalErrorBit;
       }
-      myTotalInstructionCount++;
     }
 
     // See if we need to handle an interrupt
@@ -308,7 +256,7 @@ void M6502::interruptHandler()
   // Handle the interrupt
   if((myExecutionStatus & MaskableInterruptBit) && !I)
   {
-    mySystem->incrementCycles(7 * mySystemCyclesPerProcessorCycle);
+    mySystem->incrementCycles(7 * SYSTEM_CYCLES_PER_CPU);
     mySystem->poke(0x0100 + SP--, (PC - 1) >> 8);
     mySystem->poke(0x0100 + SP--, (PC - 1) & 0x00ff);
     mySystem->poke(0x0100 + SP--, PS() & (~0x10));
@@ -318,7 +266,7 @@ void M6502::interruptHandler()
   }
   else if(myExecutionStatus & NonmaskableInterruptBit)
   {
-    mySystem->incrementCycles(7 * mySystemCyclesPerProcessorCycle);
+    mySystem->incrementCycles(7 * SYSTEM_CYCLES_PER_CPU);
     mySystem->poke(0x0100 + SP--, (PC - 1) >> 8);
     mySystem->poke(0x0100 + SP--, (PC - 1) & 0x00ff);
     mySystem->poke(0x0100 + SP--, PS() & (~0x10));
@@ -418,7 +366,7 @@ bool M6502::load(Serializer& in)
   }
   catch(...)
   {
-    cerr << "ERROR: M6502::laod" << endl;
+    cerr << "ERROR: M6502::load" << endl;
     return false;
   }
 
@@ -434,11 +382,11 @@ void M6502::attach(Debugger& debugger)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 M6502::addCondBreak(Expression *e, const string& name)
+uInt32 M6502::addCondBreak(Expression* e, const string& name)
 {
-  myBreakConds.push_back(e);
+  myBreakConds.emplace_back(unique_ptr<Expression>(e));
   myBreakCondNames.push_back(name);
-  return myBreakConds.size() - 1;
+  return (uInt32)myBreakConds.size() - 1;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -446,18 +394,14 @@ void M6502::delCondBreak(uInt32 brk)
 {
   if(brk < myBreakConds.size())
   {
-    delete myBreakConds[brk];
-    myBreakConds.remove_at(brk);
-    myBreakCondNames.remove_at(brk);
+    Vec::removeAt(myBreakConds, brk);
+    Vec::removeAt(myBreakCondNames, brk);
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void M6502::clearCondBreaks()
 {
-  for(uInt32 i = 0; i < myBreakConds.size(); i++)
-    delete myBreakConds[i];
-
   myBreakConds.clear();
   myBreakCondNames.clear();
 }
@@ -467,48 +411,4 @@ const StringList& M6502::getCondBreakNames() const
 {
   return myBreakCondNames;
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Int32 M6502::evalCondBreaks()
-{
-  for(uInt32 i = 0; i < myBreakConds.size(); i++)
-    if(myBreakConds[i]->evaluate())
-      return i;
-
-  return -1; // no break hit
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void M6502::setBreakPoints(PackedBitArray *bp)
-{
-  myBreakPoints = bp;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void M6502::setTraps(PackedBitArray *read, PackedBitArray *write)
-{
-  myReadTraps = read;
-  myWriteTraps = write;
-}
-#endif
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 M6502::ourInstructionCycleTable[256] = {
-//  0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
-    7, 6, 2, 8, 3, 3, 5, 5, 3, 2, 2, 2, 4, 4, 6, 6,  // 0
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7,  // 1
-    6, 6, 2, 8, 3, 3, 5, 5, 4, 2, 2, 2, 4, 4, 6, 6,  // 2
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7,  // 3
-    6, 6, 2, 8, 3, 3, 5, 5, 3, 2, 2, 2, 3, 4, 6, 6,  // 4
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7,  // 5
-    6, 6, 2, 8, 3, 3, 5, 5, 4, 2, 2, 2, 5, 4, 6, 6,  // 6
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7,  // 7
-    2, 6, 2, 6, 3, 3, 3, 3, 2, 2, 2, 2, 4, 4, 4, 4,  // 8
-    2, 6, 2, 6, 4, 4, 4, 4, 2, 5, 2, 5, 5, 5, 5, 5,  // 9
-    2, 6, 2, 6, 3, 3, 3, 4, 2, 2, 2, 2, 4, 4, 4, 4,  // a
-    2, 5, 2, 5, 4, 4, 4, 4, 2, 4, 2, 4, 4, 4, 4, 4,  // b
-    2, 6, 2, 8, 3, 3, 5, 5, 2, 2, 2, 2, 4, 4, 6, 6,  // c
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7,  // d
-    2, 6, 2, 8, 3, 3, 5, 5, 2, 2, 2, 2, 4, 4, 6, 6,  // e
-    2, 5, 2, 8, 4, 4, 6, 6, 2, 4, 2, 7, 4, 4, 7, 7   // f
-};
+#endif  // DEBUGGER_SUPPORT
