@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: M6532.cxx 2959 2014-07-24 16:24:27Z stephena $
+// $Id: M6532.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -30,7 +30,9 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 M6532::M6532(const Console& console, const Settings& settings)
   : myConsole(console),
-    mySettings(settings)
+    mySettings(settings),
+    myTimerFlagValid(false),
+    myEdgeDetectPositive(false)
 {
 }
  
@@ -77,15 +79,15 @@ void M6532::systemCyclesReset()
   myCyclesWhenTimerSet -= mySystem->cycles();
 
   // We should also inform any 'smart' controllers as well
-  myConsole.controller(Controller::Left).systemCyclesReset();
-  myConsole.controller(Controller::Right).systemCyclesReset();
+  myConsole.leftController().systemCyclesReset();
+  myConsole.rightController().systemCyclesReset();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void M6532::update()
 {
-  Controller& port0 = myConsole.controller(Controller::Left);
-  Controller& port1 = myConsole.controller(Controller::Right);
+  Controller& port0 = myConsole.leftController();
+  Controller& port1 = myConsole.rightController();
 
   // Get current PA7 state
   bool prevPA7 = port0.myDigitalPinState[Controller::Four];
@@ -115,20 +117,14 @@ void M6532::install(System& system, Device& device)
 {
   // Remember which system I'm installed in
   mySystem = &system;
-
-  uInt16 shift = mySystem->pageShift();
-  uInt16 mask = mySystem->pageMask();
-
-  // Make sure the system we're being installed in has a page size that'll work
-  assert((0x1080 & mask) == 0);
   
   // All accesses are to the given device
   System::PageAccess access(&device, System::PA_READWRITE);
 
   // We're installing in a 2600 system
-  for(int address = 0; address < 8192; address += (1 << shift))
+  for(int address = 0; address < 8192; address += (1 << System::PAGE_SHIFT))
     if((address & 0x1080) == 0x0080)
-      mySystem->setPageAccess(address >> shift, access);
+      mySystem->setPageAccess(address >> System::PAGE_SHIFT, access);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -147,8 +143,8 @@ uInt8 M6532::peek(uInt16 addr)
   {
     case 0x00:    // SWCHA - Port A I/O Register (Joystick)
     {
-      uInt8 value = (myConsole.controller(Controller::Left).read() << 4) |
-                     myConsole.controller(Controller::Right).read();
+      uInt8 value = (myConsole.leftController().read() << 4) |
+                     myConsole.rightController().read();
 
       // Each pin is high (1) by default and will only go low (0) if either
       //  (a) External device drives the pin low
@@ -315,8 +311,8 @@ void M6532::setPinState(bool swcha)
       if(DDR bit is input)       set output as 1
       else if(DDR bit is output) set output as bit in ORA
   */
-  Controller& port0 = myConsole.controller(Controller::Left);
-  Controller& port1 = myConsole.controller(Controller::Right);
+  Controller& port0 = myConsole.leftController();
+  Controller& port1 = myConsole.rightController();
 
   uInt8 ioport = myOutA | ~myDDRA;
 
@@ -443,18 +439,3 @@ Int32 M6532::intimClocks() const
   else
     return timer & 0xff;
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-M6532::M6532(const M6532& c)
-  : myConsole(c.myConsole),
-    mySettings(c.mySettings)
-{
-  assert(false);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-M6532& M6532::operator = (const M6532&)
-{
-  assert(false);
-  return *this;
-}
