@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: MT24LC256.cxx 2937 2014-06-29 23:25:53Z stephena $
+// $Id: MT24LC256.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -58,7 +58,19 @@ MT24LC256::MT24LC256(const string& filename, const System& system)
     myCyclesWhenSCLSet(0),
     myDataFile(filename),
     myDataFileExists(false),
-    myDataChanged(false)
+    myDataChanged(false),
+    jpee_mdat(0),
+    jpee_sdat(0),
+    jpee_mclk(0),
+    jpee_sizemask(0),
+    jpee_pagemask(0),
+    jpee_smallmode(0),
+    jpee_logmode(0),
+    jpee_pptr(0),
+    jpee_state(0),
+    jpee_nb(0),
+    jpee_address(0),
+    jpee_ad_known(0)
 {
   // Load the data from an external file (if it exists)
   ifstream in;
@@ -99,7 +111,7 @@ MT24LC256::~MT24LC256()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool MT24LC256::readSDA()
+bool MT24LC256::readSDA() const
 {
   return jpee_mdat && jpee_sdat;
 }
@@ -211,8 +223,6 @@ void MT24LC256::jpee_data_start()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void MT24LC256::jpee_data_stop()
 {
-  int i;
-
   if (jpee_state == 1 && jpee_nb != 1)
   {
     JPEE_LOG0("I2C_WARNING ABANDON_WRITE");
@@ -233,7 +243,7 @@ void MT24LC256::jpee_data_stop()
       jpee_pptr = 4+jpee_pagemask-(jpee_address & jpee_pagemask);
       JPEE_LOG1("I2C_WARNING PAGECROSSING!(Truncate to %d bytes)",jpee_pptr-3);
     }
-    for (i=3; i<jpee_pptr; i++)
+    for (int i=3; i<jpee_pptr; i++)
     {
       myDataChanged = true;
       myData[(jpee_address++) & jpee_sizemask] = jpee_packet[i];
@@ -260,7 +270,7 @@ void MT24LC256::jpee_clock_fall()
       {
         if (!jpee_pptr)
         {
-          jpee_packet[0] = (unsigned char)jpee_nb;
+          jpee_packet[0] = (uInt8)jpee_nb;
           if (jpee_smallmode && ((jpee_nb & 0xF0) == 0xA0))
           {
             jpee_packet[1] = (jpee_nb >> 1) & 7;
@@ -302,7 +312,7 @@ void MT24LC256::jpee_clock_fall()
       {
         if (!jpee_pptr)
         {
-          jpee_packet[0] = (unsigned char)jpee_nb;
+          jpee_packet[0] = (uInt8)jpee_nb;
           if (jpee_smallmode)
             jpee_pptr=2;
           else
@@ -311,7 +321,7 @@ void MT24LC256::jpee_clock_fall()
         else if (jpee_pptr < 70)
         {
           JPEE_LOG1("I2C_SENT(%02X)",jpee_nb & 0xFF);
-          jpee_packet[jpee_pptr++] = (unsigned char)jpee_nb;
+          jpee_packet[jpee_pptr++] = (uInt8)jpee_nb;
           jpee_address = (jpee_packet[1] << 8) | jpee_packet[2];
           if (jpee_pptr > 2)
             jpee_ad_known = 1;
@@ -384,18 +394,3 @@ int MT24LC256::jpee_logproc(char const *st)
   cerr << "    " << st << endl;
   return 0;
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-MT24LC256::MT24LC256(const MT24LC256& c)
-  : mySystem(c.mySystem),
-    myDataFile(c.myDataFile)
-{
-  assert(false);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-MT24LC256& MT24LC256::operator = (const MT24LC256&)
-{
-  assert(false);
-  return *this;
-}
