@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: OSystem.cxx 2926 2014-06-16 16:34:48Z stephena $
+// $Id: OSystem.cxx 3148 2015-03-15 17:36:46Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -39,15 +39,6 @@
   #include "CheatManager.hxx"
 #endif
 
-#include "SerialPort.hxx"
-#if defined(BSPF_UNIX)
-  #include "SerialPortUNIX.hxx"
-#elif defined(BSPF_WINDOWS)
-  #include "SerialPortWINDOWS.hxx"
-#elif defined(BSPF_MAC_OSX)
-  #include "SerialPortMACOSX.hxx"
-#endif
-
 #include "FSNode.hxx"
 #include "MD5.hxx"
 #include "Cart.hxx"
@@ -60,6 +51,7 @@
 #include "Widget.hxx"
 #include "Console.hxx"
 #include "Random.hxx"
+#include "SerialPort.hxx"
 #include "StateManager.hxx"
 #include "Version.hxx"
 
@@ -67,26 +59,9 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 OSystem::OSystem()
-  : myEventHandler(NULL),
-    myFrameBuffer(NULL),
-    mySound(NULL),
-    mySettings(NULL),
-    myPropSet(NULL),
-    myConsole(NULL),
-    mySerialPort(NULL),
-    myMenu(NULL),
-    myCommandMenu(NULL),
-    myLauncher(NULL),
+  : myConsole(nullptr),
     myLauncherUsed(false),
-    myDebugger(NULL),
-    myCheatManager(NULL),
-    myStateManager(NULL),
-    myPNGLib(NULL),
-    myQuitLoop(false),
-    myRomFile(""),
-    myRomMD5(""),
-    myFeatures(""),
-    myBuildInfo("")
+    myQuitLoop(false)
 {
   // Calculate startup time
   myMillisAtStart = (uInt32)(time(NULL) * 1000);
@@ -116,41 +91,12 @@ OSystem::OSystem()
   myBuildInfo = info.str();
 
   mySettings = MediaFactory::createSettings(*this);
+  myRandom = make_ptr<Random>(*this);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 OSystem::~OSystem()
 {
-  delete myMenu;
-  delete myCommandMenu;
-  delete myLauncher;
-
-  // Remove any game console that is currently attached
-  deleteConsole();
-
-  // These must be deleted after all the others
-  // This is a bit hacky, since it depends on ordering
-  // of d'tor calls
-#ifdef DEBUGGER_SUPPORT
-  delete myDebugger;
-#endif
-#ifdef CHEATCODE_SUPPORT
-  delete myCheatManager;
-#endif
-
-  delete myStateManager;
-  delete myPropSet;
-
-  delete mySerialPort;
-  delete myPNGLib;
-  delete myZipHandler;
-
-  // OSystem takes responsibility for these, since it called MediaFactory
-  // to create them
-  delete myFrameBuffer;
-  delete mySound;
-  delete myEventHandler;
-  delete mySettings;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -174,7 +120,8 @@ bool OSystem::create()
   // Get relevant information about the video hardware
   // This must be done before any graphics context is created, since
   // it may be needed to initialize the size of graphical objects
-  myFrameBuffer = MediaFactory::createVideo(*this);
+  try        { myFrameBuffer = MediaFactory::createVideo(*this); }
+  catch(...) { return false; }
   if(!myFrameBuffer->initialize())
     return false;
 
@@ -183,18 +130,18 @@ bool OSystem::create()
   myEventHandler->initialize();
 
   // Create a properties set for us to use and set it up
-  myPropSet = new PropertiesSet(this);
+  myPropSet = make_ptr<PropertiesSet>(propertiesFile());
 
 #ifdef CHEATCODE_SUPPORT
-  myCheatManager = new CheatManager(this);
+  myCheatManager = make_ptr<CheatManager>(*this);
   myCheatManager->loadCheatDatabase();
 #endif
 
   // Create menu and launcher GUI objects
-  myMenu = new Menu(this);
-  myCommandMenu = new CommandMenu(this);
-  myLauncher = new Launcher(this);
-  myStateManager = new StateManager(this);
+  myMenu = make_ptr<Menu>(*this);
+  myCommandMenu = make_ptr<CommandMenu>(*this);
+  myLauncher = make_ptr<Launcher>(*this);
+  myStateManager = make_ptr<StateManager>(*this);
 
   // Create the sound object; the sound subsystem isn't actually
   // opened until needed, so this is non-blocking (on those systems
@@ -204,25 +151,13 @@ bool OSystem::create()
   // Create the serial port object
   // This is used by any controller that wants to directly access
   // a real serial port on the system
-#if defined(BSPF_UNIX)
-  mySerialPort = new SerialPortUNIX();
-#elif defined(BSPF_WINDOWS)
-  mySerialPort = new SerialPortWINDOWS();
-#elif defined(BSPF_MAC_OSX)
-  mySerialPort = new SerialPortMACOSX();
-#else
-  // Create an 'empty' serial port
-  mySerialPort = new SerialPort();
-#endif
+  mySerialPort = MediaFactory::createSerialPort();
 
-  // Let the random class know about us; it needs access to getTicks()
-  Random::setSystem(this);
+  // Re-initialize random seed
+  myRandom->initSeed();
 
   // Create PNG handler
-  myPNGLib = new PNGLibrary(*myFrameBuffer);
-
-  // Create ZIP handler
-  myZipHandler = new ZipHandler();
+  myPNGLib = make_ptr<PNGLibrary>(*myFrameBuffer);
 
   return true;
 }
@@ -240,19 +175,10 @@ void OSystem::saveConfig()
   if(myFrameBuffer)
     myFrameBuffer->tiaSurface().ntsc().saveConfig(*mySettings);
 
-  mySettings->saveConfig();
+  if(mySettings)
+    mySettings->saveConfig();
 }
 
-#ifdef DEBUGGER_SUPPORT
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void OSystem::createDebugger(Console& console)
-{
-  delete myDebugger;  myDebugger = NULL;
-  myDebugger = new Debugger(*this, console);
-  myDebugger->initialize();
-}
-#endif
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void OSystem::setConfigPaths()
 {
@@ -362,9 +288,6 @@ void OSystem::createSound()
 string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
                               bool newrom)
 {
-  // Do a little error checking; it shouldn't be necessary
-  if(myConsole) deleteConsole();
-
   bool showmessage = false;
 
   // If same ROM has been given, we reload the current one (assuming one exists)
@@ -388,11 +311,11 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
   string type, id;
   try
   {
+    closeConsole();
     myConsole = openConsole(myRomFile, myRomMD5, type, id);
   }
   catch(const char* err_msg)
   {
-    myConsole = 0;
     buf << "ERROR: Couldn't create console (" << err_msg << ")";
     logMessage(buf.str(), 0);
     return buf.str();
@@ -401,7 +324,9 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
   if(myConsole)
   {
   #ifdef DEBUGGER_SUPPORT
-    myConsole->addDebugger();
+    myDebugger = make_ptr<Debugger>(*this, *myConsole);
+    myDebugger->initialize();
+    myConsole->attachDebugger(*myDebugger);
   #endif
   #ifdef CHEATCODE_SUPPORT
     myCheatManager->loadCheats(myRomMD5);
@@ -425,7 +350,7 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
     }
     buf << "Game console created:" << endl
         << "  ROM file: " << myRomFile.getShortPath() << endl << endl
-        << getROMInfo(myConsole) << endl;
+        << getROMInfo(*myConsole) << endl;
     logMessage(buf.str(), 1);
 
     // Update the timing info for a new console run
@@ -471,42 +396,20 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
   return EmptyString;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void OSystem::deleteConsole()
-{
-  if(myConsole)
-  {
-    mySound->close();
-  #ifdef CHEATCODE_SUPPORT
-    myCheatManager->saveCheats(myConsole->properties().get(Cartridge_MD5));
-  #endif
-    ostringstream buf;
-    double executionTime   = (double) myTimingInfo.totalTime / 1000000.0;
-    double framesPerSecond = (double) myTimingInfo.totalFrames / executionTime;
-    buf << "Game console stats:" << endl
-        << "  Total frames drawn: " << myTimingInfo.totalFrames << endl
-        << "  Total time (sec):   " << executionTime << endl
-        << "  Frames per second:  " << framesPerSecond << endl
-        << endl;
-    logMessage(buf.str(), 1);
-
-    delete myConsole;  myConsole = NULL;
-  #ifdef DEBUGGER_SUPPORT
-    delete myDebugger; myDebugger = NULL;
-  #endif
-  }
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool OSystem::reloadConsole()
 {
-  deleteConsole();
   return createConsole(myRomFile, myRomMD5, false) == EmptyString;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool OSystem::createLauncher(const string& startdir)
 {
+  closeConsole();
+
+  if(mySound)
+    mySound->close();
+
   mySettings->setValue("tmpromdir", startdir);
   bool status = false;
 
@@ -515,7 +418,6 @@ bool OSystem::createLauncher(const string& startdir)
   {
     myLauncher->reStack();
     myFrameBuffer->setCursorState();
-    myFrameBuffer->refresh();
 
     setFramerate(60);
     resetLoopTiming();
@@ -532,7 +434,7 @@ bool OSystem::createLauncher(const string& startdir)
 string OSystem::getROMInfo(const FilesystemNode& romfile)
 {
   string md5, type, id, result = "";
-  Console* console = 0;
+  unique_ptr<Console> console;
   try
   {
     console = openConsole(romfile, md5, type, id);
@@ -544,8 +446,7 @@ string OSystem::getROMInfo(const FilesystemNode& romfile)
     return buf.str();
   }
 
-  result = getROMInfo(console);
-  delete console;
+  result = getROMInfo(*console);
   return result;
 }
 
@@ -566,17 +467,13 @@ void OSystem::logMessage(const string& message, uInt8 level)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Console* OSystem::openConsole(const FilesystemNode& romfile, string& md5,
-                              string& type, string& id)
+unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile,
+                                         string& md5, string& type, string& id)
 {
-#define CMDLINE_PROPS_UPDATE(cl_name, prop_name) \
-  s = mySettings->getString(cl_name);            \
-  if(s != "") props.set(prop_name, s);
-
-  Console* console = (Console*) NULL;
+  unique_ptr<Console> console;
 
   // Open the cartridge image and read it in
-  uInt8* image = 0;
+  uInt8* image = nullptr;
   uInt32 size  = 0;
   if((image = openROM(romfile, md5, size)) != 0)
   {
@@ -584,7 +481,13 @@ Console* OSystem::openConsole(const FilesystemNode& romfile, string& md5,
     // For initial creation of the Cart, we're only concerned with the BS type
     Properties props;
     myPropSet->getMD5(md5, props);
-    string s = "";
+
+    auto CMDLINE_PROPS_UPDATE = [&](const string& name, PropertyType prop)
+    {
+      const string& s = mySettings->getString(name);
+      if(s != "") props.set(prop, s);
+    };
+
     CMDLINE_PROPS_UPDATE("bs", Cartridge_Type);
     CMDLINE_PROPS_UPDATE("type", Cartridge_Type);
 
@@ -614,7 +517,7 @@ Console* OSystem::openConsole(const FilesystemNode& romfile, string& md5,
     CMDLINE_PROPS_UPDATE("sp", Console_SwapPorts);
     CMDLINE_PROPS_UPDATE("lc", Controller_Left);
     CMDLINE_PROPS_UPDATE("rc", Controller_Right);
-    s = mySettings->getString("bc");
+    const string& s = mySettings->getString("bc");
     if(s != "") { props.set(Controller_Left, s); props.set(Controller_Right, s); }
     CMDLINE_PROPS_UPDATE("cp", Controller_SwapPaddles);
     CMDLINE_PROPS_UPDATE("ma", Controller_MouseAxis);
@@ -626,7 +529,7 @@ Console* OSystem::openConsole(const FilesystemNode& romfile, string& md5,
 
     // Finally, create the cart with the correct properties
     if(cart)
-      console = new Console(*this, *cart, props);
+      console = make_ptr<Console>(*this, cart, props);
   }
 
   // Free the image since we don't need it any longer
@@ -636,6 +539,19 @@ Console* OSystem::openConsole(const FilesystemNode& romfile, string& md5,
   return console;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void OSystem::closeConsole()
+{
+  if(myConsole)
+  {
+  #ifdef CHEATCODE_SUPPORT
+    // If a previous console existed, save cheats before creating a new one
+    myCheatManager->saveCheats(myConsole->properties().get(Cartridge_MD5));
+  #endif
+    myConsole.release();
+  }
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt8* OSystem::openROM(const FilesystemNode& rom, string& md5, uInt32& size)
 {
@@ -644,11 +560,11 @@ uInt8* OSystem::openROM(const FilesystemNode& rom, string& md5, uInt32& size)
   // but also adds a properties entry if the one for the ROM doesn't
   // contain a valid name
 
-  uInt8* image = 0;
+  uInt8* image = nullptr;
   if((size = rom.read(image)) == 0)
   {
     delete[] image;
-    return (uInt8*) 0;
+    return nullptr;
   }
 
   // If we get to this point, we know we have a valid file to open
@@ -667,9 +583,9 @@ uInt8* OSystem::openROM(const FilesystemNode& rom, string& md5, uInt32& size)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystem::getROMInfo(const Console* console)
+string OSystem::getROMInfo(const Console& console)
 {
-  const ConsoleInfo& info = console->about();
+  const ConsoleInfo& info = console.about();
   ostringstream buf;
 
   buf << "  Cart Name:       " << info.CartName << endl
@@ -705,81 +621,6 @@ void OSystem::validatePath(string& path, const string& setting,
   mySettings->setValue(setting, node.getShortPath());
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void OSystem::setDefaultJoymap(Event::Type event, EventMode mode)
-{
-#define SET_DEFAULT_AXIS(sda_event, sda_mode, sda_stick, sda_axis, sda_val, sda_cmp_event) \
-  if(eraseAll || sda_cmp_event == sda_event) \
-    myEventHandler->addJoyAxisMapping(sda_event, sda_mode, sda_stick, sda_axis, sda_val, false);
-
-#define SET_DEFAULT_BTN(sdb_event, sdb_mode, sdb_stick, sdb_button, sdb_cmp_event) \
-  if(eraseAll || sdb_cmp_event == sdb_event) \
-    myEventHandler->addJoyButtonMapping(sdb_event, sdb_mode, sdb_stick, sdb_button, false);
-
-#define SET_DEFAULT_HAT(sdh_event, sdh_mode, sdh_stick, sdh_hat, sdh_dir, sdh_cmp_event) \
-  if(eraseAll || sdh_cmp_event == sdh_event) \
-    myEventHandler->addJoyHatMapping(sdh_event, sdh_mode, sdh_stick, sdh_hat, sdh_dir, false);
-
-  bool eraseAll = (event == Event::NoType);
-  switch(mode)
-  {
-    case kEmulationMode:  // Default emulation events
-      // Left joystick left/right directions (assume joystick zero)
-      SET_DEFAULT_AXIS(Event::JoystickZeroLeft, mode, 0, 0, 0, event);
-      SET_DEFAULT_AXIS(Event::JoystickZeroRight, mode, 0, 0, 1, event);
-      // Left joystick up/down directions (assume joystick zero)
-      SET_DEFAULT_AXIS(Event::JoystickZeroUp, mode, 0, 1, 0, event);
-      SET_DEFAULT_AXIS(Event::JoystickZeroDown, mode, 0, 1, 1, event);
-      // Right joystick left/right directions (assume joystick one)
-      SET_DEFAULT_AXIS(Event::JoystickOneLeft, mode, 1, 0, 0, event);
-      SET_DEFAULT_AXIS(Event::JoystickOneRight, mode, 1, 0, 1, event);
-      // Right joystick left/right directions (assume joystick one)
-      SET_DEFAULT_AXIS(Event::JoystickOneUp, mode, 1, 1, 0, event);
-      SET_DEFAULT_AXIS(Event::JoystickOneDown, mode, 1, 1, 1, event);
-
-      // Left joystick (assume joystick zero, button zero)
-      SET_DEFAULT_BTN(Event::JoystickZeroFire, mode, 0, 0, event);
-      // Right joystick (assume joystick one, button zero)
-      SET_DEFAULT_BTN(Event::JoystickOneFire, mode, 1, 0, event);
-
-      // Left joystick left/right directions (assume joystick zero and hat 0)
-      SET_DEFAULT_HAT(Event::JoystickZeroLeft, mode, 0, 0, EVENT_HATLEFT, event);
-      SET_DEFAULT_HAT(Event::JoystickZeroRight, mode, 0, 0, EVENT_HATRIGHT, event);
-      // Left joystick up/down directions (assume joystick zero and hat 0)
-      SET_DEFAULT_HAT(Event::JoystickZeroUp, mode, 0, 0, EVENT_HATUP, event);
-      SET_DEFAULT_HAT(Event::JoystickZeroDown, mode, 0, 0, EVENT_HATDOWN, event);
-      // Right joystick left/right directions (assume joystick one and hat 0)
-      SET_DEFAULT_HAT(Event::JoystickOneLeft, mode, 1, 0, EVENT_HATLEFT, event);
-      SET_DEFAULT_HAT(Event::JoystickOneRight, mode, 1, 0, EVENT_HATRIGHT, event);
-      // Right joystick up/down directions (assume joystick one and hat 0)
-      SET_DEFAULT_HAT(Event::JoystickOneUp, mode, 1, 0, EVENT_HATUP, event);
-      SET_DEFAULT_HAT(Event::JoystickOneDown, mode, 1, 0, EVENT_HATDOWN, event);
-
-      break;
-
-    case kMenuMode:  // Default menu/UI events
-      SET_DEFAULT_AXIS(Event::UILeft, mode, 0, 0, 0, event);
-      SET_DEFAULT_AXIS(Event::UIRight, mode, 0, 0, 1, event);
-      SET_DEFAULT_AXIS(Event::UIUp, mode, 0, 1, 0, event);
-      SET_DEFAULT_AXIS(Event::UIDown, mode, 0, 1, 1, event);
-
-      // Left joystick (assume joystick zero, button zero)
-      SET_DEFAULT_BTN(Event::UISelect, mode, 0, 0, event);
-      // Right joystick (assume joystick one, button zero)
-      SET_DEFAULT_BTN(Event::UISelect, mode, 1, 0, event);
-
-      SET_DEFAULT_HAT(Event::UILeft, mode, 0, 0, EVENT_HATLEFT, event);
-      SET_DEFAULT_HAT(Event::UIRight, mode, 0, 0, EVENT_HATRIGHT, event);
-      SET_DEFAULT_HAT(Event::UIUp, mode, 0, 0, EVENT_HATUP, event);
-      SET_DEFAULT_HAT(Event::UIDown, mode, 0, 0, EVENT_HATDOWN, event);
-
-      break;
-
-    default:
-      break;
-  }
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt64 OSystem::getTicks() const
 {
@@ -847,19 +688,12 @@ void OSystem::mainLoop()
       myTimingInfo.totalFrames++;
     }
   }
-}
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-OSystem::OSystem(const OSystem& osystem)
-{
-}
+  // Cleanup time
+#ifdef CHEATCODE_SUPPORT
+  if(myConsole)
+    myCheatManager->saveCheats(myConsole->properties().get(Cartridge_MD5));
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-OSystem& OSystem::operator = (const OSystem&)
-{
-  assert(false);
-  return *this;
+  myCheatManager->saveCheatDatabase();
+#endif
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-ZipHandler* OSystem::myZipHandler = 0;
