@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Settings.cxx 2908 2014-06-04 16:01:45Z stephena $
+// $Id: Settings.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -121,6 +121,7 @@ Settings::Settings(OSystem& osystem)
     GUI::Size(DebuggerDialog::kMediumFontMinW,
               DebuggerDialog::kMediumFontMinH));
 #endif
+  setInternal("uipalette", "standard");
   setInternal("listdelay", "300");
   setInternal("mwheel", "4");
 
@@ -129,7 +130,7 @@ Settings::Settings(OSystem& osystem)
   setInternal("loglevel", "1");
   setInternal("logtoconsole", "0");
   setInternal("tiadriven", "false");
-  setInternal("cpurandom", "true");
+  setInternal("cpurandom", "");
   setInternal("ramrandom", "true");
   setInternal("avoxport", "");
   setInternal("stats", "false");
@@ -156,8 +157,6 @@ Settings::Settings(OSystem& osystem)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Settings::~Settings()
 {
-  myInternalSettings.clear();
-  myExternalSettings.clear();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -329,7 +328,7 @@ void Settings::validate()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Settings::usage()
+void Settings::usage() const
 {
   cout << endl
     << "Stella version " << STELLA_VERSION << endl
@@ -503,9 +502,9 @@ void Settings::saveConfig()
   // Do a quick scan of the internal settings to see if any have
   // changed.  If not, we don't need to save them at all.
   bool settingsChanged = false;
-  for(unsigned int i = 0; i < myInternalSettings.size(); ++i)
+  for(const auto& s: myInternalSettings)
   {
-    if(myInternalSettings[i].value != myInternalSettings[i].initialValue)
+    if(s.value != s.initialValue)
     {
       settingsChanged = true;
       break;
@@ -538,11 +537,8 @@ void Settings::saveConfig()
       << ";" << endl;
 
   // Write out each of the key and value pairs
-  for(unsigned int i = 0; i < myInternalSettings.size(); ++i)
-  {
-    out << myInternalSettings[i].key << " = " <<
-           myInternalSettings[i].value << endl;
-  }
+  for(const auto& s: myInternalSettings)
+    out << s.key << " = " << s.value << endl;
 
   out.close();
 }
@@ -550,7 +546,7 @@ void Settings::saveConfig()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int Settings::getInternalPos(const string& key) const
 {
-  for(unsigned int i = 0; i < myInternalSettings.size(); ++i)
+  for(uInt32 i = 0; i < myInternalSettings.size(); ++i)
     if(myInternalSettings[i].key == key)
       return i;
 
@@ -560,7 +556,7 @@ int Settings::getInternalPos(const string& key) const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int Settings::getExternalPos(const string& key) const
 {
-  for(unsigned int i = 0; i < myExternalSettings.size(); ++i)
+  for(uInt32 i = 0; i < myExternalSettings.size(); ++i)
     if(myExternalSettings[i].key == key)
       return i;
 
@@ -573,14 +569,14 @@ int Settings::setInternal(const string& key, const Variant& value,
 {
   int idx = -1;
 
-  if(pos != -1 && pos >= 0 && pos < (int)myInternalSettings.size() &&
+  if(pos >= 0 && pos < (int)myInternalSettings.size() &&
      myInternalSettings[pos].key == key)
   {
     idx = pos;
   }
   else
   {
-    for(unsigned int i = 0; i < myInternalSettings.size(); ++i)
+    for(uInt32 i = 0; i < myInternalSettings.size(); ++i)
     {
       if(myInternalSettings[i].key == key)
       {
@@ -610,7 +606,7 @@ int Settings::setInternal(const string& key, const Variant& value,
     if(useAsInitial) setting.initialValue = value;
 
     myInternalSettings.push_back(setting);
-    idx = myInternalSettings.size() - 1;
+    idx = int(myInternalSettings.size()) - 1;
 
     /*cerr << "insert internal: key = " << key
          << ", value  = " << value
@@ -628,14 +624,14 @@ int Settings::setExternal(const string& key, const Variant& value,
 {
   int idx = -1;
 
-  if(pos != -1 && pos >= 0 && pos < (int)myExternalSettings.size() &&
+  if(pos >= 0 && pos < (int)myExternalSettings.size() &&
      myExternalSettings[pos].key == key)
   {
     idx = pos;
   }
   else
   {
-    for(unsigned int i = 0; i < myExternalSettings.size(); ++i)
+    for(uInt32 i = 0; i < myExternalSettings.size(); ++i)
     {
       if(myExternalSettings[i].key == key)
       {
@@ -664,7 +660,7 @@ int Settings::setExternal(const string& key, const Variant& value,
     if(useAsInitial) setting.initialValue = value;
 
     myExternalSettings.push_back(setting);
-    idx = myExternalSettings.size() - 1;
+    idx = int(myExternalSettings.size()) - 1;
 
     /*cerr << "insert external: key = " << key
          << ", value = " << value
@@ -674,17 +670,3 @@ int Settings::setExternal(const string& key, const Variant& value,
 
   return idx;
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Settings::Settings(const Settings& s)
-  : myOSystem(s.myOSystem)
-{
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Settings& Settings::operator = (const Settings&)
-{
-  assert(false);
-
-  return *this;
-}
