@@ -8,13 +8,13 @@
 // MM     MM 66  66 55  55 00  00 22
 // MM     MM  6666   5555   0000  222222
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: System.cxx 2959 2014-07-24 16:24:27Z stephena $
+// $Id: System.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -24,35 +24,28 @@
 #include "M6502.hxx"
 #include "M6532.hxx"
 #include "TIA.hxx"
+#include "Cart.hxx"
 #include "System.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-System::System(uInt16 n, uInt16 m)
-  : myAddressMask((1 << n) - 1),
-    myPageShift(m),
-    myPageMask((1 << m) - 1),
-    myNumberOfPages(1 << (n - m)),
-    myNumberOfDevices(0),
-    myM6502(0),
-    myTIA(0),
+System::System(const OSystem& osystem, M6502& m6502, M6532& m6532,
+               TIA& mTIA, Cartridge& mCart)
+  : myOSystem(osystem),
+    myM6502(m6502),
+    myM6532(m6532),
+    myTIA(mTIA),
+    myCart(mCart),
     myCycles(0),
     myDataBusState(0),
     myDataBusLocked(false),
     mySystemInAutodetect(false)
 {
-  // Make sure the arguments are reasonable
-  assert((1 <= m) && (m <= n) && (n <= 16));
-
-  // Create a new random number generator
-  myRandom = new Random();
-
-  // Allocate page table and dirty list
-  myPageAccessTable = new PageAccess[myNumberOfPages];
-  myPageIsDirtyTable = new bool[myNumberOfPages];
+  // Re-initialize random generator
+  randGenerator().initSeed();
 
   // Initialize page access table
   PageAccess access(&myNullDevice, System::PA_READ);
-  for(int page = 0; page < myNumberOfPages; ++page)
+  for(int page = 0; page < NUM_PAGES; ++page)
   {
     setPageAccess(page, access);
     myPageIsDirtyTable[page] = false;
@@ -65,21 +58,16 @@ System::System(uInt16 n, uInt16 m)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 System::~System()
 {
-  // Free the devices attached to me, since I own them
-  for(uInt32 i = 0; i < myNumberOfDevices; ++i)
-  {
-    delete myDevices[i];
-  }
+}
 
-  // Free the M6502 that I own
-  delete myM6502;
-
-  // Free my page access table and dirty list
-  delete[] myPageAccessTable;
-  delete[] myPageIsDirtyTable;
-
-  // Free the random number generator
-  delete myRandom;
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void System::initialize()
+{
+  // Install all devices
+  myM6532.install(*this);
+  myTIA.install(*this);
+  myCart.install(*this);
+  myM6502.install(*this);  // Must always be installed last
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -91,65 +79,23 @@ void System::reset(bool autodetect)
   // Reset system cycle counter
   resetCycles();
 
-  // First we reset the devices attached to myself
-  for(uInt32 i = 0; i < myNumberOfDevices; ++i)
-    myDevices[i]->reset();
-
-  // Now we reset the processor if it exists
-  if(myM6502 != 0)
-    myM6502->reset();
+  // Reset all devices
+  myM6532.reset();
+  myTIA.reset();
+  myCart.reset();
+  myM6502.reset();  // Must always be reset last
 
   // There are no dirty pages upon startup
   clearDirtyPages();
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::attach(Device* device)
-{
-  assert(myNumberOfDevices < 100);
-
-  // Add device to my collection of devices
-  myDevices[myNumberOfDevices++] = device;
-
-  // Ask the device to install itself
-  device->install(*this);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::attach(M6502* m6502)
-{
-  // Remember the processor
-  myM6502 = m6502;
-
-  // Ask the processor to install itself
-  myM6502->install(*this);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::attach(M6532* m6532)
-{
-  // Remember the processor
-  myM6532 = m6532;
-
-  // Attach it as a normal device
-  attach((Device*) m6532);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::attach(TIA* tia)
-{
-  myTIA = tia;
-  attach((Device*) tia);
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void System::resetCycles()
 {
   // First we let all of the device attached to me know about the reset
-  for(uInt32 i = 0; i < myNumberOfDevices; ++i)
-  {
-    myDevices[i]->systemCyclesReset();
-  }
+  myM6532.systemCyclesReset();
+  myTIA.systemCyclesReset();
+  myCart.systemCyclesReset();
 
   // Now, we reset cycle count to zero
   myCycles = 0;
@@ -159,7 +105,7 @@ void System::resetCycles()
 void System::setPageAccess(uInt16 page, const PageAccess& access)
 {
   // Make sure the page is within range
-  assert(page < myNumberOfPages);
+  assert(page < NUM_PAGES);
 
   // Make sure the access methods make sense
   assert(access.device != 0);
@@ -171,7 +117,7 @@ void System::setPageAccess(uInt16 page, const PageAccess& access)
 const System::PageAccess& System::getPageAccess(uInt16 page) const
 {
   // Make sure the page is within range
-  assert(page < myNumberOfPages);
+  assert(page < NUM_PAGES);
 
   return myPageAccessTable[page];
 }
@@ -179,20 +125,20 @@ const System::PageAccess& System::getPageAccess(uInt16 page) const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 System::PageAccessType System::getPageAccessType(uInt16 addr) const
 {
-  return myPageAccessTable[(addr & myAddressMask) >> myPageShift].type;
+  return myPageAccessTable[(addr & ADDRESS_MASK) >> PAGE_SHIFT].type;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void System::setDirtyPage(uInt16 addr)
 {
-  myPageIsDirtyTable[(addr & myAddressMask) >> myPageShift] = true;
+  myPageIsDirtyTable[(addr & ADDRESS_MASK) >> PAGE_SHIFT] = true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool System::isPageDirty(uInt16 start_addr, uInt16 end_addr) const
 {
-  uInt16 start_page = (start_addr & myAddressMask) >> myPageShift;
-  uInt16 end_page = (end_addr & myAddressMask) >> myPageShift;
+  uInt16 start_page = (start_addr & ADDRESS_MASK) >> PAGE_SHIFT;
+  uInt16 end_page = (end_addr & ADDRESS_MASK) >> PAGE_SHIFT;
 
   for(uInt16 page = start_page; page <= end_page; ++page)
     if(myPageIsDirtyTable[page])
@@ -204,19 +150,19 @@ bool System::isPageDirty(uInt16 start_addr, uInt16 end_addr) const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void System::clearDirtyPages()
 {
-  for(uInt32 i = 0; i < myNumberOfPages; ++i)
+  for(uInt32 i = 0; i < NUM_PAGES; ++i)
     myPageIsDirtyTable[i] = false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt8 System::peek(uInt16 addr, uInt8 flags)
 {
-  PageAccess& access = myPageAccessTable[(addr & myAddressMask) >> myPageShift];
+  PageAccess& access = myPageAccessTable[(addr & ADDRESS_MASK) >> PAGE_SHIFT];
 
 #ifdef DEBUGGER_SUPPORT
   // Set access type
   if(access.codeAccessBase)
-    *(access.codeAccessBase + (addr & myPageMask)) |= flags;
+    *(access.codeAccessBase + (addr & PAGE_MASK)) |= flags;
   else
     access.device->setAccessFlags(addr, flags);
 #endif
@@ -224,7 +170,7 @@ uInt8 System::peek(uInt16 addr, uInt8 flags)
   // See if this page uses direct accessing or not 
   uInt8 result;
   if(access.directPeekBase)
-    result = *(access.directPeekBase + (addr & myPageMask));
+    result = *(access.directPeekBase + (addr & PAGE_MASK));
   else
     result = access.device->peek(addr);
 
@@ -239,14 +185,14 @@ uInt8 System::peek(uInt16 addr, uInt8 flags)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void System::poke(uInt16 addr, uInt8 value)
 {
-  uInt16 page = (addr & myAddressMask) >> myPageShift;
+  uInt16 page = (addr & ADDRESS_MASK) >> PAGE_SHIFT;
   PageAccess& access = myPageAccessTable[page];
-  
+
   // See if this page uses direct accessing or not 
   if(access.directPokeBase)
   {
     // Since we have direct access to this poke, we can dirty its page
-    *(access.directPokeBase + (addr & myPageMask)) = value;
+    *(access.directPokeBase + (addr & PAGE_MASK)) = value;
     myPageIsDirtyTable[page] = true;
   }
   else
@@ -262,13 +208,13 @@ void System::poke(uInt16 addr, uInt8 value)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt8 System::getAccessFlags(uInt16 addr)
+uInt8 System::getAccessFlags(uInt16 addr) const
 {
 #ifdef DEBUGGER_SUPPORT
-  PageAccess& access = myPageAccessTable[(addr & myAddressMask) >> myPageShift];
+  const PageAccess& access = myPageAccessTable[(addr & ADDRESS_MASK) >> PAGE_SHIFT];
 
   if(access.codeAccessBase)
-    return *(access.codeAccessBase + (addr & myPageMask));
+    return *(access.codeAccessBase + (addr & PAGE_MASK));
   else
     return access.device->getAccessFlags(addr);
 #else
@@ -280,27 +226,15 @@ uInt8 System::getAccessFlags(uInt16 addr)
 void System::setAccessFlags(uInt16 addr, uInt8 flags)
 {
 #ifdef DEBUGGER_SUPPORT
-  PageAccess& access = myPageAccessTable[(addr & myAddressMask) >> myPageShift];
+  PageAccess& access = myPageAccessTable[(addr & ADDRESS_MASK) >> PAGE_SHIFT];
 
   if(access.codeAccessBase)
-    *(access.codeAccessBase + (addr & myPageMask)) |= flags;
+    *(access.codeAccessBase + (addr & PAGE_MASK)) |= flags;
   else
     access.device->setAccessFlags(addr, flags);
 #endif
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::lockDataBus()
-{
-  myDataBusLocked = true;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void System::unlockDataBus()
-{
-  myDataBusLocked = false;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool System::save(Serializer& out) const
 {
@@ -310,13 +244,15 @@ bool System::save(Serializer& out) const
     out.putInt(myCycles);
     out.putByte(myDataBusState);
 
-    if(!myM6502->save(out))
+    // Save the state of each device
+    if(!myM6502.save(out))
+      return false;
+    if(!myM6532.save(out))
+      return false;
+    if(!myTIA.save(out))
+      return false;
+    if(!myCart.save(out))
       return false;
-
-    // Now save the state of each device
-    for(uInt32 i = 0; i < myNumberOfDevices; ++i)
-      if(!myDevices[i]->save(out))
-        return false;
   }
   catch(...)
   {
@@ -338,14 +274,15 @@ bool System::load(Serializer& in)
     myCycles = in.getInt();
     myDataBusState = in.getByte();
 
-    // Next, load state for the CPU
-    if(!myM6502->load(in))
+    // Load the state of each device
+    if(!myM6502.load(in))
+      return false;
+    if(!myM6532.load(in))
+      return false;
+    if(!myTIA.load(in))
+      return false;
+    if(!myCart.load(in))
       return false;
-
-    // Now load the state of each device
-    for(uInt32 i = 0; i < myNumberOfDevices; ++i)
-      if(!myDevices[i]->load(in))
-        return false;
   }
   catch(...)
   {
@@ -355,20 +292,3 @@ bool System::load(Serializer& in)
 
   return true;
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-System::System(const System& s)
-  : myAddressMask(s.myAddressMask),
-    myPageShift(s.myPageShift),
-    myPageMask(s.myPageMask),
-    myNumberOfPages(s.myNumberOfPages)
-{
-  assert(false);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-System& System::operator = (const System&)
-{
-  assert(false);
-  return *this;
-}
