@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: TIASurface.cxx 2987 2014-09-01 21:17:33Z stephena $
+// $Id: TIASurface.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <cmath>
@@ -31,21 +31,18 @@
 TIASurface::TIASurface(OSystem& system)
   : myOSystem(system),
     myFB(system.frameBuffer()),
-    myTIA(NULL),
-    myTiaSurface(NULL),
-    mySLineSurface(NULL),
-    myBaseTiaSurface(NULL),
+    myTIA(nullptr),
     myFilterType(kNormal),
     myUsePhosphor(false),
     myPhosphorBlend(77),
-    myScanlinesEnabled(false)
+    myScanlinesEnabled(false),
+    myPalette(nullptr)
 {
   // Load NTSC filter settings
   myNTSCFilter.loadConfig(myOSystem.settings());
 
   // Create a surface for the TIA image and scanlines; we'll need them eventually
-  uInt32 tiaID = myFB.allocateSurface(ATARI_NTSC_OUT_WIDTH(kTIAW), kTIAH);
-  myTiaSurface = myFB.surface(tiaID);
+  myTiaSurface = myFB.allocateSurface(ATARI_NTSC_OUT_WIDTH(kTIAW), kTIAH);
 
   // Generate scanline data, and a pre-defined scanline surface
   uInt32 scanData[kScanH];
@@ -54,17 +51,10 @@ TIASurface::TIASurface(OSystem& system)
     scanData[i]   = 0x00000000;
     scanData[i+1] = 0xff000000;
   }
-  uInt32 scanID = myFB.allocateSurface(1, kScanH, scanData);
-  mySLineSurface = myFB.surface(scanID);
+  mySLineSurface = myFB.allocateSurface(1, kScanH, scanData);
 
   // Base TIA surface for use in taking snapshots in 1x mode
-  uInt32 baseID = myFB.allocateSurface(kTIAW*2, kTIAH);
-  myBaseTiaSurface = myFB.surface(baseID);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-TIASurface::~TIASurface()
-{
+  myBaseTiaSurface = myFB.allocateSurface(kTIAW*2, kTIAH);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
