@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CheckListWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: CheckListWidget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //============================================================================
 
 #include "CheckListWidget.hxx"
@@ -33,7 +33,7 @@ CheckListWidget::CheckListWidget(GuiObject* boss, const GUI::Font& font,
   _rows = h / _fontHeight;
 
   // Create a CheckboxWidget for each row in the list
-  CheckboxWidget* t;
+  CheckboxWidget* t = nullptr;
   for(int i = 0; i < _rows; ++i)
   {
     t = new CheckboxWidget(boss, font, _x + 2, ypos, "", kCheckActionCmd);
@@ -65,7 +65,7 @@ void CheckListWidget::setList(const StringList& list, const BoolArray& state)
 
   // Then turn off any extras
   if((int)_stateList.size() < _rows)
-    for(int i = _stateList.size(); i < _rows; ++i)
+    for(int i = (int)_stateList.size(); i < _rows; ++i)
       _checkList[i]->clearFlags(WIDGET_ENABLED);
 
   ListWidget::recalc();
@@ -86,9 +86,7 @@ void CheckListWidget::drawWidget(bool hilite)
 {
 //cerr << "CheckListWidget::drawWidget\n";
   FBSurface& s = _boss->dialog().surface();
-  int i, pos, len = _list.size();
-  string buffer;
-  int deltax;
+  int i, pos, len = (int)_list.size();
 
   // Draw a thin frame around the list and to separate columns
   s.hLine(_x, _y, _x + _w - 1, kColor);
@@ -122,19 +120,12 @@ void CheckListWidget::drawWidget(bool hilite)
 
     if (_selectedItem == pos && _editMode)
     {
-      buffer = _editString;
       adjustOffset();
-      deltax = -_editScrollOffset;
-
-      s.drawString(_font, buffer, _x + r.left, y, r.width(), kTextColor,
-                   kTextAlignLeft, deltax, false);
+      s.drawString(_font, editString(), _x + r.left, y, r.width(), kTextColor,
+                   kTextAlignLeft, -_editScrollOffset, false);
     }
     else
-    {
-      buffer = _list[pos];
-      deltax = 0;
-      s.drawString(_font, buffer, _x + r.left, y, r.width(), kTextColor);
-    }
+      s.drawString(_font, _list[pos], _x + r.left, y, r.width(), kTextColor);
   }
 
   // Only draw the caret while editing, and if it's in the current viewport
