@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CommandMenu.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: CommandMenu.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "Dialog.hxx"
@@ -22,10 +22,10 @@
 #include "CommandMenu.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CommandMenu::CommandMenu(OSystem* osystem)
+CommandMenu::CommandMenu(OSystem& osystem)
   : DialogContainer(osystem)
 {
-  myBaseDialog = new CommandDialog(myOSystem, this);
+  myBaseDialog = new CommandDialog(myOSystem, *this);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
