@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Dialog.cxx 2978 2014-08-24 21:47:51Z stephena $
+// $Id: Dialog.cxx 3159 2015-04-22 15:02:17Z stephena $
 //
 //   Based on code from ScummVM - Scumm Interpreter
 //   Copyright (C) 2002-2004 The ScummVM project
@@ -26,6 +26,7 @@
 #include "Dialog.hxx"
 #include "Widget.hxx"
 #include "TabWidget.hxx"
+#include "Vec.hxx"
 
 /*
  * TODO list
@@ -36,17 +37,17 @@
  * ...
  */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Dialog::Dialog(OSystem* instance, DialogContainer* parent,
+Dialog::Dialog(OSystem& instance, DialogContainer& parent,
                int x, int y, int w, int h)
-  : GuiObject(*instance, *parent, *this, x, y, w, h),
-    _mouseWidget(0),
-    _focusedWidget(0),
-    _dragWidget(0),
-    _okWidget(0),
-    _cancelWidget(0),
+  : GuiObject(instance, parent, *this, x, y, w, h),
+    _mouseWidget(nullptr),
+    _focusedWidget(nullptr),
+    _dragWidget(nullptr),
+    _okWidget(nullptr),
+    _cancelWidget(nullptr),
     _visible(false),
     _processCancel(false),
-    _surface(0),
+    _surface(nullptr),
     _tabID(0)
 {
 }
@@ -58,7 +59,7 @@ Dialog::~Dialog()
   _myTabList.clear();
 
   delete _firstWidget;
-  _firstWidget = NULL;
+  _firstWidget = nullptr;
 
   _buttonGroup.clear();
 }
@@ -69,11 +70,8 @@ void Dialog::open(bool refresh)
   // Make sure we have a valid surface to draw into
   // Technically, this shouldn't be needed until drawDialog(), but some
   // dialogs cause drawing to occur within loadConfig()
-  if(_surface == NULL)
-  {
-    uInt32 surfaceID = instance().frameBuffer().allocateSurface(_w, _h);
-    _surface = instance().frameBuffer().surface(surfaceID);
-  }
+  if(_surface == nullptr)
+    _surface = instance().frameBuffer().allocateSurface(_w, _h);
   parent().addDialog(this);
 
   center();
@@ -84,9 +82,6 @@ void Dialog::open(bool refresh)
   buildCurrentFocusList();
 
   _visible = true;
-
-  if(refresh)
-    instance().frameBuffer().refresh();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -95,7 +90,7 @@ void Dialog::close(bool refresh)
   if (_mouseWidget)
   {
     _mouseWidget->handleMouseLeft(0);
-    _mouseWidget = 0;
+    _mouseWidget = nullptr;
   }
 
   releaseFocus();
@@ -103,9 +98,6 @@ void Dialog::close(bool refresh)
   _visible = false;
 
   parent().removeDialog();
-
-  if(refresh)
-    instance().frameBuffer().refresh();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -126,7 +118,7 @@ void Dialog::releaseFocus()
   if(_focusedWidget)
   {
     _focusedWidget->lostFocus();
-    _focusedWidget = 0;
+    _focusedWidget = nullptr;
   }
 }
 
@@ -147,10 +139,10 @@ void Dialog::addFocusWidget(Widget* w)
 void Dialog::addToFocusList(WidgetArray& list)
 {
   // All focusable widgets should retain focus
-  for(uInt32 i = 0; i < list.size(); ++i)
-    list[i]->setFlags(WIDGET_RETAIN_FOCUS);
+  for(const auto& w: list)
+    w->setFlags(WIDGET_RETAIN_FOCUS);
 
-  _myFocus.list.push_back(list);
+  Vec::append(_myFocus.list, list);
   _focusList = _myFocus.list;
 
   if(list.size() > 0)
@@ -167,8 +159,8 @@ void Dialog::addToFocusList(WidgetArray& list, TabWidget* w, int tabId)
   assert(w == _myTabList[w->getID()].widget);
 
   // All focusable widgets should retain focus
-  for(uInt32 i = 0; i < list.size(); ++i)
-    list[i]->setFlags(WIDGET_RETAIN_FOCUS);
+  for(const auto& fw: list)
+    fw->setFlags(WIDGET_RETAIN_FOCUS);
 
   // First get the appropriate focus list
   FocusList& focus = _myTabList[w->getID()].focus;
@@ -176,14 +168,14 @@ void Dialog::addToFocusList(WidgetArray& list, TabWidget* w, int tabId)
   // Now insert in the correct place in that focus list
   uInt32 id = tabId;
   if(id < focus.size())
-    focus[id].list.push_back(list);
+    Vec::append(focus[id].list, list);
   else
   {
     // Make sure the array is large enough
     while(focus.size() <= id)
       focus.push_back(Focus());
 
-    focus[id].list.push_back(list);
+    Vec::append(focus[id].list, list);
   }
 
   if(list.size() > 0)
@@ -228,7 +220,7 @@ void Dialog::buildCurrentFocusList(int tabID)
 
   // Remember which tab item previously had focus, if applicable
   // This only applies if this method was called for a tab change
-  Widget* tabFocusWidget = 0;
+  Widget* tabFocusWidget = nullptr;
   if(tabID >= 0 && tabID < (int)_myTabList.size())
   {
     // Save focus in previously selected tab column,
@@ -241,17 +233,17 @@ void Dialog::buildCurrentFocusList(int tabID)
   }
 
   // Add appropriate items from tablist (if present)
-  for(uInt32 id = 0; id < _myTabList.size(); ++id)
-    _myTabList[id].appendFocusList(_focusList);
+  for(auto& tabfocus: _myTabList)
+    tabfocus.appendFocusList(_focusList);
 
   // Add remaining items from main focus list
-  _focusList.push_back(_myFocus.list);
+  Vec::append(_focusList, _myFocus.list);
 
   // Add button group at end of current focus list
   // We do it this way for TabWidget, so that buttons are scanned
   // *after* the widgets in the current tab
   if(_buttonGroup.size() > 0)
-    _focusList.push_back(_buttonGroup);
+    Vec::append(_focusList, _buttonGroup);
 
   // Finally, the moment we've all been waiting for :)
   // Set the actual focus widget
@@ -262,23 +254,11 @@ void Dialog::buildCurrentFocusList(int tabID)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::redrawFocus()
-{
-  if(_focusedWidget)
-    _focusedWidget = Widget::setFocusForChain(this, getFocusList(), _focusedWidget, 0);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::addSurface(FBSurface* surface)
+void Dialog::addSurface(shared_ptr<FBSurface> surface)
 {
   mySurfaceStack.push(surface);
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::draw()
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::drawDialog()
 {
@@ -306,7 +286,11 @@ void Dialog::drawDialog()
     }
 
     // Draw outlines for focused widgets
-    redrawFocus();
+    // Don't change focus, since this will trigger lost and received
+    // focus events
+    if(_focusedWidget)
+      _focusedWidget = Widget::setFocusForChain(this, getFocusList(),
+                          _focusedWidget, 0, false);
 
     // Tell the surface(s) this area is dirty
     s.setDirty();
@@ -656,7 +640,7 @@ void Dialog::handleCommand(CommandSender* sender, int cmd, int data, int id)
  * in the local coordinate system, i.e. relative to the top left of the dialog.
  */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Widget* Dialog::findWidget(int x, int y)
+Widget* Dialog::findWidget(int x, int y) const
 {
   return Widget::findWidgetInChain(_firstWidget, x, y);
 }
@@ -705,7 +689,6 @@ Dialog::Focus::Focus(Widget* w)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Dialog::Focus::~Focus()
 {
-  list.clear();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -718,7 +701,6 @@ Dialog::TabFocus::TabFocus(TabWidget* w)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Dialog::TabFocus::~TabFocus()
 {
-  focus.clear();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -727,7 +709,7 @@ void Dialog::TabFocus::appendFocusList(WidgetArray& list)
   int active = widget->getActiveTab();
 
   if(active >= 0 && active < (int)focus.size())
-    list.push_back(focus[active].list);
+    Vec::append(list, focus[active].list);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -743,5 +725,5 @@ Widget* Dialog::TabFocus::getNewFocus()
 {
   currentTab = widget->getActiveTab();
 
-  return (currentTab < focus.size()) ? focus[currentTab].widget : 0;
+  return (currentTab < focus.size()) ? focus[currentTab].widget : nullptr;
 }
