@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EditTextWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: EditTextWidget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -29,7 +29,6 @@
 EditTextWidget::EditTextWidget(GuiObject* boss, const GUI::Font& font,
                                int x, int y, int w, int h, const string& text)
   : EditableWidget(boss, font, x, y, w, h + 2, text),
-    _editable(true),
     _changed(false)
 {
   _flags = WIDGET_ENABLED | WIDGET_CLEARBG | WIDGET_RETAIN_FOCUS;
@@ -43,38 +42,33 @@ void EditTextWidget::setText(const string& str, bool changed)
   EditableWidget::setText(str, changed);
   _backupString = str;
   _changed = changed;
-
-  setDirty(); draw();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditTextWidget::handleMouseDown(int x, int y, int button, int clickCount)
 {
-  if(!_editable)
+  if(!isEditable())
     return;
 
   x += _editScrollOffset;
 
   int width = 0;
-  unsigned int i;
+  uInt32 i;
 
-  for (i = 0; i < _editString.size(); ++i)
+  for (i = 0; i < editString().size(); ++i)
   {
-    width += _font.getCharWidth(_editString[i]);
+    width += _font.getCharWidth(editString()[i]);
     if (width >= x)
       break;
   }
 
   if (setCaretPos(i))
-  {
-    setDirty(); draw();
-  }
+    setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditTextWidget::drawWidget(bool hilite)
 {
-//cerr << "EditTextWidget::drawWidget\n";
   FBSurface& s = _boss->dialog().surface();
 
   // Highlight changes
@@ -89,7 +83,7 @@ void EditTextWidget::drawWidget(bool hilite)
 
   // Draw the text
   adjustOffset();
-  s.drawString(_font, _editString, _x + 2, _y + 2, getEditRect().width(),
+  s.drawString(_font, editString(), _x + 2, _y + 2, getEditRect().width(),
                !_changed ? _textcolor : kDbgChangedTextColor,
                kTextAlignLeft, -_editScrollOffset, false);
 
@@ -108,7 +102,7 @@ GUI::Rect EditTextWidget::getEditRect() const
 void EditTextWidget::lostFocusWidget()
 {
   // If we loose focus, 'commit' the user changes
-  _backupString = _editString;
+  _backupString = editString();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
