@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EditableWidget.cxx 2926 2014-06-16 16:34:48Z stephena $
+// $Id: EditableWidget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //============================================================================
 
 #include "Dialog.hxx"
@@ -40,6 +40,9 @@ EditableWidget::EditableWidget(GuiObject* boss, const GUI::Font& font,
   _bgcolorhi = kWidColor;
   _textcolor = kTextColor;
   _textcolorhi = kTextColor;
+
+  // By default, include all printable chars except quotes
+  _filter = [](char c) { return isprint(c) && c != '\"'; };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -50,35 +53,34 @@ EditableWidget::~EditableWidget()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditableWidget::setText(const string& str, bool)
 {
-  // TODO: We probably should filter the input string here,
-  // e.g. using tryInsertChar.
-  _editString = str;
+  // Filter input string
+  _editString = "";
+  for(char c: str)
+    if(_filter(tolower(c)))
+      _editString.push_back(c);
+
   _caretPos = (int)_editString.size();
 
   _editScrollOffset = (_font.getStringWidth(_editString) - (getEditRect().width()));
   if (_editScrollOffset < 0)
     _editScrollOffset = 0;
 
-  if(_editable)
-    startEditMode();
-
-  // Make sure the new string is seen onscreen
-  setDirty(); draw();
+  setDirty();
 }
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditableWidget::setEditable(bool editable)
 {
   _editable = editable;
   if(_editable)
-    setFlags(WIDGET_WANTS_RAWDATA|WIDGET_RETAIN_FOCUS);
+    setFlags(WIDGET_WANTS_RAWDATA | WIDGET_RETAIN_FOCUS);
   else
-    clearFlags(WIDGET_WANTS_RAWDATA|WIDGET_RETAIN_FOCUS);
+    clearFlags(WIDGET_WANTS_RAWDATA | WIDGET_RETAIN_FOCUS);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool EditableWidget::tryInsertChar(char c, int pos)
 {
-  if(isprint(c) && c != '\"')
+  if(_filter(tolower(c)))
   {
     _editString.insert(pos, 1, c);
     return true;
@@ -96,7 +98,7 @@ bool EditableWidget::handleText(char text)
   {
     _caretPos++;
     sendCommand(EditableWidget::kChangedCmd, 0, _id);
-    setDirty(); draw();
+    setDirty();
     return true;
   }
   return false;
@@ -173,9 +175,7 @@ bool EditableWidget::handleKeyDown(StellaKey key, StellaMod mod)
   }
 
   if (dirty)
-  {
-    setDirty(); draw();
-  }
+    setDirty();
 
   return handled;
 }
@@ -195,7 +195,6 @@ int EditableWidget::getCaretOffset() const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditableWidget::drawCaret()
 {
-//cerr << "EditableWidget::drawCaret()\n";
   // Only draw if item is visible
   if (!_editable || !isVisible() || !_boss->isVisible() || !_hasFocus)
     return;
