@@ -8,23 +8,21 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: InputDialog.cxx 2913 2014-06-10 16:43:35Z stephena $
+// $Id: InputDialog.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include "bspf.hxx"
 
-#include "Array.hxx"
 #include "OSystem.hxx"
 #include "Joystick.hxx"
 #include "Paddles.hxx"
 #include "Settings.hxx"
-#include "StringList.hxx"
 #include "EventMappingWidget.hxx"
 #include "EditTextWidget.hxx"
 #include "PopUpWidget.hxx"
@@ -35,9 +33,9 @@
 
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-InputDialog::InputDialog(OSystem* osystem, DialogContainer* parent,
+InputDialog::InputDialog(OSystem& osystem, DialogContainer& parent,
                          const GUI::Font& font, int max_w, int max_h)
-  : Dialog(osystem, parent, 0, 0, 0, 0)
+  : Dialog(osystem, parent)
 {
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
@@ -45,12 +43,11 @@ InputDialog::InputDialog(OSystem* osystem, DialogContainer* parent,
             buttonHeight = font.getLineHeight() + 4;
   const int vBorder = 4;
   int xpos, ypos, tabID;
-  WidgetArray wid;
   StringList actions;
 
   // Set real dimensions
   _w = BSPF_min(50 * fontWidth + 10, max_w);
-  _h = BSPF_min(14 * (lineHeight + 4) + 14, max_h);
+  _h = BSPF_min(15 * (lineHeight + 4) + 14, max_h);
 
   // The tab widget
   xpos = 2; ypos = vBorder;
@@ -59,7 +56,7 @@ InputDialog::InputDialog(OSystem* osystem, DialogContainer* parent,
 
   // 1) Event mapper for emulation actions
   tabID = myTab->addTab("Emul. Events");
-  instance().eventHandler().getActionList(kEmulationMode, actions);
+  actions = instance().eventHandler().getActionList(kEmulationMode);
   myEmulEventMapper = new EventMappingWidget(myTab, font, 2, 2,
                                              myTab->getWidth(),
                                              myTab->getHeight() - ypos,
@@ -69,8 +66,7 @@ InputDialog::InputDialog(OSystem* osystem, DialogContainer* parent,
 
   // 2) Event mapper for UI actions
   tabID = myTab->addTab("UI Events");
-  actions.clear();
-  instance().eventHandler().getActionList(kMenuMode, actions);
+  actions = instance().eventHandler().getActionList(kMenuMode);
   myMenuEventMapper = new EventMappingWidget(myTab, font, 2, 2,
                                              myTab->getWidth(),
                                              myTab->getHeight() - ypos,
@@ -86,7 +82,7 @@ InputDialog::InputDialog(OSystem* osystem, DialogContainer* parent,
   myTab->setActiveTab(0);
 
   // Add Defaults, OK and Cancel buttons
-  wid.clear();
+  WidgetArray wid;
   ButtonWidget* b;
   b = new ButtonWidget(this, font, 10, _h - buttonHeight - 10,
                        buttonWidth, buttonHeight, "Defaults", kDefaultsCmd);
@@ -118,9 +114,8 @@ void InputDialog::addDevicePortTab(const GUI::Font& font)
   lwidth = font.getStringWidth("Use mouse as a controller: ");
   pwidth = font.getStringWidth("Analog devices");
 
-  items.clear();
-  items.push_back("Left / Right", "lr");
-  items.push_back("Right / Left", "rl");
+  VarList::push_back(items, "Left / Right", "lr");
+  VarList::push_back(items, "Right / Left", "rl");
   mySAPort = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight, items,
                              "Stelladaptor port order: ", lwidth);
   wid.push_back(mySAPort);
@@ -128,9 +123,9 @@ void InputDialog::addDevicePortTab(const GUI::Font& font)
   // Use mouse as controller
   ypos += lineHeight + 5;
   items.clear();
-  items.push_back("Always", "always");
-  items.push_back("Analog devices", "analog");
-  items.push_back("Never", "never");
+  VarList::push_back(items, "Always", "always");
+  VarList::push_back(items, "Analog devices", "analog");
+  VarList::push_back(items, "Never", "never");
   myMouseControl = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight, items,
                              "Use mouse as a controller: ", lwidth);
   wid.push_back(myMouseControl);
@@ -207,6 +202,19 @@ void InputDialog::addDevicePortTab(const GUI::Font& font)
   myHideCursor->clearFlags(WIDGET_ENABLED);
 #endif
 
+  // Enable/disable control key-combos
+  ypos += lineHeight + 4;
+  myCtrlCombo = new CheckboxWidget(myTab, font, xpos, ypos,
+	                "Use Control key combos");
+  wid.push_back(myCtrlCombo);
+
+  // Show joystick database
+  xpos += 20;  ypos += lineHeight + 8;
+  myJoyDlgButton = new ButtonWidget(myTab, font, xpos, ypos,
+    font.getStringWidth("Show Joystick Database") + 20, font.getLineHeight() + 4,
+    "Show Joystick Database", kDBButtonPressed);
+  wid.push_back(myJoyDlgButton);
+
   // Add items for virtual device ports
   addToFocusList(wid, myTab, tabID);
 }
@@ -243,6 +251,9 @@ void InputDialog::loadConfig()
   // Hide cursor
   myHideCursor->setState(instance().settings().getBool("hidecursor"));
 
+  // Enable/disable control key-combos
+  myCtrlCombo->setState(instance().settings().getBool("ctrlcombo"));
+
   myTab->loadConfig();
 }
 
@@ -282,6 +293,9 @@ void InputDialog::saveConfig()
   instance().settings().setValue("grabmouse", myGrabMouse->getState());	 
   instance().settings().setValue("hidecursor", myHideCursor->getState());	 
   instance().frameBuffer().setCursorState();
+
+  // Enable/disable control key-combos
+  instance().settings().setValue("ctrlcombo", myCtrlCombo->getState());	 
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -327,6 +341,9 @@ void InputDialog::setDefaults()
       // Hide cursor
       myHideCursor->setState(false);
 
+      // Enable/disable control key-combos
+      myCtrlCombo->setState(true);
+
       break;
     }
 
@@ -417,6 +434,13 @@ void InputDialog::handleCommand(CommandSender* sender, int cmd,
       myMPaddleLabel->setValue(myMPaddleSpeed->getValue());
       break;
 
+    case kDBButtonPressed:
+      if(!myJoyDialog)
+        myJoyDialog = make_ptr<JoystickDialog>
+                          (this, instance().frameBuffer().font(), _w-60, _h-60);
+      myJoyDialog->show();
+      break;
+
     default:
       Dialog::handleCommand(sender, cmd, data, 0);
   }
