@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ListWidget.cxx 2916 2014-06-11 16:06:17Z stephena $
+// $Id: ListWidget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //============================================================================
 
 #include <cctype>
@@ -68,8 +68,11 @@ ListWidget::~ListWidget()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void ListWidget::setSelected(int item)
 {
-  if(item < -1 || item >= (int)_list.size())
+  if(item < 0 || item >= (int)_list.size())
+  {
+    setDirty();  // Simply redraw and exit
     return;
+  }
 
   if(isEnabled())
   {
@@ -88,21 +91,21 @@ void ListWidget::setSelected(int item)
 void ListWidget::setSelected(const string& item)
 {
   int selected = -1;
-  if(!_list.isEmpty())
+  if(!_list.empty())
   {
     if(item == "")
       selected = 0;
     else
     {
       uInt32 itemToSelect = 0;
-      StringList::const_iterator iter;
-      for(iter = _list.begin(); iter != _list.end(); ++iter, ++itemToSelect)
+      for(const auto& iter: _list)
       {
-        if(item == *iter)
+        if(item == iter)
         {
           selected = itemToSelect;
           break;
         }
+        ++itemToSelect;
       }
       if(itemToSelect > _list.size() || selected == -1)
         selected = 0;
@@ -144,7 +147,7 @@ const string& ListWidget::getSelectedString() const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void ListWidget::scrollTo(int item)
 {
-  int size = _list.size();
+  int size = (int)_list.size();
   if (item >= size)
     item = size - 1;
   if (item < 0)
@@ -160,7 +163,7 @@ void ListWidget::scrollTo(int item)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void ListWidget::recalc()
 {
-  int size = _list.size();
+  int size = (int)_list.size();
 
   if (_currentPos >= size)
     _currentPos = size - 1;
@@ -172,7 +175,7 @@ void ListWidget::recalc()
 
   _editMode = false;
 
-  _scrollBar->_numEntries     = _list.size();
+  _scrollBar->_numEntries     = (int)_list.size();
   _scrollBar->_entriesPerPage = _rows;
 
   // Reset to normal data entry
@@ -205,7 +208,7 @@ void ListWidget::handleMouseDown(int x, int y, int button, int clickCount)
       abortEditMode();
     _selectedItem = newSelectedItem;
     sendCommand(ListWidget::kSelectionChangedCmd, _selectedItem, _id);
-    setDirty(); draw();
+    setDirty();
   }
 	
   // TODO: Determine where inside the string the user clicked and place the
@@ -222,7 +225,7 @@ void ListWidget::handleMouseUp(int x, int y, int button, int clickCount)
     sendCommand(ListWidget::kDoubleClickedCmd, _selectedItem, _id);
 
     // Start edit mode
-    if(_editable && !_editMode)
+    if(isEditable() && !_editMode)
       startEditMode();
   }
 }
@@ -264,9 +267,9 @@ bool ListWidget::handleText(char text)
     // quite big lists to deal with -- so for now we can live with this lazy
     // implementation :-)
     int newSelectedItem = 0;
-    for (StringList::const_iterator i = _list.begin(); i != _list.end(); ++i)
+    for(const auto& i: _list)
     {
-      if(BSPF_startsWithIgnoreCase(*i, _quickSelectStr))
+      if(BSPF_startsWithIgnoreCase(i, _quickSelectStr))
       {
         _selectedItem = newSelectedItem;
         break;
@@ -343,7 +346,7 @@ bool ListWidget::handleEvent(Event::Type e)
     case Event::UISelect:
       if (_selectedItem >= 0)
       {
-        if (_editable)
+        if (isEditable())
           startEditMode();
         else
           sendCommand(ListWidget::kActivatedCmd, _selectedItem, _id);
@@ -369,7 +372,7 @@ bool ListWidget::handleEvent(Event::Type e)
     case Event::UIPgDown:
       _selectedItem += _rows - 1;
       if (_selectedItem >= (int)_list.size() )
-        _selectedItem = _list.size() - 1;
+        _selectedItem = (int)_list.size() - 1;
       break;
 
     case Event::UIHome:
@@ -377,7 +380,7 @@ bool ListWidget::handleEvent(Event::Type e)
       break;
 
     case Event::UIEnd:
-      _selectedItem = _list.size() - 1;
+      _selectedItem = (int)_list.size() - 1;
       break;
 
     case Event::UIPrevDir:
@@ -417,7 +420,7 @@ void ListWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
       if (_currentPos != (int)data)
       {
         _currentPos = data;
-        setDirty(); draw();
+        setDirty();
 
         // Let boss know the list has scrolled
         sendCommand(ListWidget::kScrolledCmd, _currentPos, _id);
@@ -444,13 +447,13 @@ void ListWidget::scrollToCurrent(int item)
   if (_currentPos < 0 || _rows > (int)_list.size())
     _currentPos = 0;
   else if (_currentPos + _rows > (int)_list.size())
-    _currentPos = _list.size() - _rows;
+    _currentPos = (int)_list.size() - _rows;
 
   int oldScrollPos = _scrollBar->_currentPos;
   _scrollBar->_currentPos = _currentPos;
   _scrollBar->recalc();
 
-  setDirty(); draw();
+  setDirty();
 
   if(oldScrollPos != _currentPos)
     sendCommand(ListWidget::kScrolledCmd, _currentPos, _id);
@@ -459,7 +462,7 @@ void ListWidget::scrollToCurrent(int item)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void ListWidget::startEditMode()
 {
-  if (_editable && !_editMode && _selectedItem >= 0)
+  if (isEditable() && !_editMode && _selectedItem >= 0)
   {
     _editMode = true;
     setText(_list[_selectedItem]);
@@ -477,7 +480,7 @@ void ListWidget::endEditMode()
 
   // Send a message that editing finished with a return/enter key press
   _editMode = false;
-  _list[_selectedItem] = _editString;
+  _list[_selectedItem] = editString();
   sendCommand(ListWidget::kDataChangedCmd, _selectedItem, _id);
 
   // Reset to normal data entry
