@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ScrollBarWidget.cxx 2833 2014-01-12 17:23:42Z stephena $
+// $Id: ScrollBarWidget.cxx 3156 2015-03-21 20:00:00Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -33,7 +33,7 @@
 #define UP_DOWN_BOX_HEIGHT	18
 
 // Up arrow
-static unsigned int up_arrow[8] = {
+static uInt32 up_arrow[8] = {
   0x00011000,
   0x00011000,
   0x00111100,
@@ -45,7 +45,7 @@ static unsigned int up_arrow[8] = {
 };
 
 // Down arrow
-static unsigned int down_arrow[8] = {
+static uInt32 down_arrow[8] = {
   0x11111111,
   0x11111111,
   0x01111110,
@@ -181,9 +181,7 @@ void ScrollBarWidget::handleMouseMoved(int x, int y, int button)
       _part = kSliderPart;
 
     if (old_part != _part)
-    {
-      setDirty(); draw();
-    }
+      setDirty();
   }
 }
 
@@ -204,8 +202,7 @@ void ScrollBarWidget::checkBounds(int old_pos)
 
   if (old_pos != _currentPos)
   {
-    recalc();  // This takes care of the required refresh
-    setDirty(); draw();
+    recalc();
     sendCommand(kSetPositionCmd, _currentPos, _id);
   }
 }
@@ -214,7 +211,6 @@ void ScrollBarWidget::checkBounds(int old_pos)
 void ScrollBarWidget::handleMouseEntered(int button)
 {
   setFlags(WIDGET_HILITED);
-  setDirty(); draw();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -222,7 +218,6 @@ void ScrollBarWidget::handleMouseLeft(int button)
 {
   _part = kNoPart;
   clearFlags(WIDGET_HILITED);
-  setDirty(); draw();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -246,7 +241,7 @@ void ScrollBarWidget::recalc()
     _sliderPos = UP_DOWN_BOX_HEIGHT;
   }
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
