@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: VideoDialog.cxx 2992 2014-09-06 00:33:17Z stephena $
+// $Id: VideoDialog.cxx 3131 2015-01-01 03:49:32Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -30,7 +30,6 @@
 #include "Console.hxx"
 #include "TIA.hxx"
 #include "Settings.hxx"
-#include "StringList.hxx"
 #include "Widget.hxx"
 #include "TabWidget.hxx"
 #include "NTSCFilter.hxx"
@@ -38,9 +37,9 @@
 #include "VideoDialog.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
+VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
                          const GUI::Font& font, int max_w, int max_h)
-  : Dialog(osystem, parent, 0, 0, 0, 0)
+  : Dialog(osystem, parent)
 {
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
@@ -64,7 +63,6 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
 
   //////////////////////////////////////////////////////////
   // 1) General options
-  wid.clear();
   tabID = myTab->addTab(" General ");
 
   // Video renderer
@@ -75,7 +73,6 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
   ypos += lineHeight + 4;
 
   // TIA filters (will be dynamically filled later)
-  items.clear();
   myTIAZoom = new PopUpWidget(myTab, font, xpos, ypos, pwidth,
                               lineHeight, items, "TIA Zoom: ", lwidth);
   wid.push_back(myTIAZoom);
@@ -83,9 +80,9 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
 
   // TIA Palette
   items.clear();
-  items.push_back("Standard", "standard");
-  items.push_back("Z26", "z26");
-  items.push_back("User", "user");
+  VarList::push_back(items, "Standard", "standard");
+  VarList::push_back(items, "Z26", "z26");
+  VarList::push_back(items, "User", "user");
   myTIAPalette = new PopUpWidget(myTab, font, xpos, ypos, pwidth,
                                  lineHeight, items, "TIA Palette: ", lwidth);
   wid.push_back(myTIAPalette);
@@ -93,8 +90,8 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
 
   // TIA interpolation
   items.clear();
-  items.push_back("Linear", "linear");
-  items.push_back("Nearest", "nearest");
+  VarList::push_back(items, "Linear", "linear");
+  VarList::push_back(items, "Nearest", "nearest");
   myTIAInterpolate = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
                                      items, "TIA Inter: ", lwidth);
   wid.push_back(myTIAInterpolate);
@@ -102,8 +99,8 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
 
   // Timing to use between frames
   items.clear();
-  items.push_back("Sleep", "sleep");
-  items.push_back("Busy-wait", "busy");
+  VarList::push_back(items, "Sleep", "sleep");
+  VarList::push_back(items, "Busy-wait", "busy");
   myFrameTiming = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
                                   items, "Timing (*): ", lwidth);
   wid.push_back(myFrameTiming);
@@ -204,12 +201,12 @@ VideoDialog::VideoDialog(OSystem* osystem, DialogContainer* parent,
 
   // TV Mode
   items.clear();
-  items.push_back("Disabled", NTSCFilter::PRESET_OFF);
-  items.push_back("Composite", NTSCFilter::PRESET_COMPOSITE);
-  items.push_back("S-Video", NTSCFilter::PRESET_SVIDEO);
-  items.push_back("RGB", NTSCFilter::PRESET_RGB);
-  items.push_back("Bad adjust", NTSCFilter::PRESET_BAD);
-  items.push_back("Custom", NTSCFilter::PRESET_CUSTOM);
+  VarList::push_back(items, "Disabled", NTSCFilter::PRESET_OFF);
+  VarList::push_back(items, "Composite", NTSCFilter::PRESET_COMPOSITE);
+  VarList::push_back(items, "S-Video", NTSCFilter::PRESET_SVIDEO);
+  VarList::push_back(items, "RGB", NTSCFilter::PRESET_RGB);
+  VarList::push_back(items, "Bad adjust", NTSCFilter::PRESET_BAD);
+  VarList::push_back(items, "Custom", NTSCFilter::PRESET_CUSTOM);
   lwidth = font.getStringWidth("TV Mode: ");
   pwidth = font.getStringWidth("Bad adjust"),
   myTVMode =
@@ -416,7 +413,7 @@ void VideoDialog::saveConfig()
   // Framerate
   int i = myFrameRate->getValue();
   instance().settings().setValue("framerate", i);
-  if(&instance().console())
+  if(instance().hasConsole())
   {
     // Make sure auto-frame calculation is only enabled when necessary
     instance().console().tia().enableAutoFrame(i <= 0);
@@ -428,7 +425,7 @@ void VideoDialog::saveConfig()
 
   // PAL color-loss effect
   instance().settings().setValue("colorloss", myColorLoss->getState());
-  if(&instance().console())
+  if(instance().hasConsole())
     instance().console().toggleColorLoss(myColorLoss->getState());
 
   // Fullscreen stretch setting
