@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Widget.cxx 2978 2014-08-24 21:47:51Z stephena $
+// $Id: Widget.cxx 3159 2015-04-22 15:02:17Z stephena $
 //
 //   Based on code from ScummVM - Scumm Interpreter
 //   Copyright (C) 2002-2004 The ScummVM project
@@ -59,7 +59,7 @@ Widget::Widget(GuiObject* boss, const GUI::Font& font,
 Widget::~Widget()
 {
   delete _next;
-  _next = NULL;
+  _next = nullptr;
 
   _focusList.clear();
 }
@@ -152,16 +152,12 @@ void Widget::lostFocus()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Widget::setEnabled(bool e)
 {
-  if(e)
-    setFlags(WIDGET_ENABLED);
-  else
-    clearFlags(WIDGET_ENABLED);
-
-  setDirty(); draw();
+  if(e) setFlags(WIDGET_ENABLED);
+  else  clearFlags(WIDGET_ENABLED);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Widget* Widget::findWidgetInChain(Widget *w, int x, int y)
+Widget* Widget::findWidgetInChain(Widget* w, int x, int y)
 {
   while(w)
   {
@@ -192,8 +188,8 @@ bool Widget::isWidgetInChain(Widget* w, Widget* find)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Widget::isWidgetInChain(WidgetArray& list, Widget* find)
 {
-  for(int i = 0; i < (int)list.size(); ++i)
-    if(list[i] == find)
+  for(const auto& w: list)
+    if(w == find)
       return true;
 
   return false;
@@ -201,10 +197,11 @@ bool Widget::isWidgetInChain(WidgetArray& list, Widget* find)
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Widget* Widget::setFocusForChain(GuiObject* boss, WidgetArray& arr,
-                                 Widget* wid, int direction)
+                                 Widget* wid, int direction,
+                                 bool emitFocusEvents)
 {
   FBSurface& s = boss->dialog().surface();
-  int size = arr.size(), pos = -1;
+  int size = (int)arr.size(), pos = -1;
   Widget* tmp;
   for(int i = 0; i < size; ++i)
   {
@@ -224,17 +221,21 @@ Widget* Widget::setFocusForChain(GuiObject* boss, WidgetArray& arr,
     // First clear area surrounding all widgets
     if(tmp->_hasFocus)
     {
-      tmp->lostFocus();
+      if(emitFocusEvents)
+        tmp->lostFocus();
+      else
+        tmp->_hasFocus = false;
+
       s.frameRect(x, y, w, h, kDlgColor);
 
-      tmp->setDirty(); tmp->draw();
+      tmp->setDirty();
       s.setDirty();
     }
   }
 
   // Figure out which which should be active
   if(pos == -1)
-    return 0;
+    return nullptr;
   else
   {
     switch(direction)
@@ -267,10 +268,14 @@ Widget* Widget::setFocusForChain(GuiObject* boss, WidgetArray& arr,
   int x = tmp->getAbsX() - 1,  y = tmp->getAbsY() - 1,
       w = tmp->getWidth() + 2, h = tmp->getHeight() + 2;
 
-  tmp->receivedFocus();
+  if(emitFocusEvents)
+    tmp->receivedFocus();
+  else
+    tmp->_hasFocus = true;
+
   s.frameRect(x, y, w, h, kWidFrameColor, kDashLine);
 
-  tmp->setDirty(); tmp->draw();
+  tmp->setDirty();
   s.setDirty();
 
   return tmp;
@@ -287,7 +292,7 @@ void Widget::setDirtyInChain(Widget* start)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-StaticTextWidget::StaticTextWidget(GuiObject *boss, const GUI::Font& font,
+StaticTextWidget::StaticTextWidget(GuiObject* boss, const GUI::Font& font,
                                    int x, int y, int w, int h,
                                    const string& text, TextAlignment align)
   : Widget(boss, font, x, y, w, h),
@@ -300,6 +305,7 @@ StaticTextWidget::StaticTextWidget(GuiObject *boss, const GUI::Font& font,
   _textcolorhi = kTextColor;
 
   _label = text;
+  _editable = false;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -309,7 +315,7 @@ void StaticTextWidget::setValue(int value)
   BSPF_snprintf(buf, 255, "%d", value);
   _label = buf;
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -317,7 +323,7 @@ void StaticTextWidget::setLabel(const string& label)
 {
   _label = label;
 
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -329,7 +335,7 @@ void StaticTextWidget::drawWidget(bool hilite)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-ButtonWidget::ButtonWidget(GuiObject *boss, const GUI::Font& font,
+ButtonWidget::ButtonWidget(GuiObject* boss, const GUI::Font& font,
                            int x, int y, int w, int h,
                            const string& label, int cmd)
   : StaticTextWidget(boss, font, x, y, w, h, label, kTextAlignCenter),
@@ -349,14 +355,14 @@ ButtonWidget::ButtonWidget(GuiObject *boss, const GUI::Font& font,
 void ButtonWidget::handleMouseEntered(int button)
 {
   setFlags(WIDGET_HILITED);
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void ButtonWidget::handleMouseLeft(int button)
 {
   clearFlags(WIDGET_HILITED);
-  setDirty(); draw();
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -396,7 +402,7 @@ void ButtonWidget::drawWidget(bool hilite)
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 /* 8x8 checkbox bitmap */
-static unsigned int checked_img_active[8] =
+static uInt32 checked_img_active[8] =
 {
 	0x11111111,
 	0x11111111,
@@ -408,7 +414,7 @@ static unsigned int checked_img_active[8] =
 	0x11111111
 };
 
-static unsigned int checked_img_inactive[8] =
+static uInt32 checked_img_inactive[8] =
 {
 	0x11111111,
 	0x11111111,
@@ -420,7 +426,7 @@ static unsigned int checked_img_inactive[8] =
 	0x11111111
 };
 
-static unsigned int checked_img_circle[8] =
+static uInt32 checked_img_circle[8] =
 {
 	0x00011000,
 	0x01111110,
@@ -433,7 +439,7 @@ static unsigned int checked_img_circle[8] =
 };
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CheckboxWidget::CheckboxWidget(GuiObject *boss, const GUI::Font& font,
+CheckboxWidget::CheckboxWidget(GuiObject* boss, const GUI::Font& font,
                                int x, int y, const string& label,
                                int cmd)
   : ButtonWidget(boss, font, x, y, 16, 16, label, cmd),
@@ -512,7 +518,7 @@ void CheckboxWidget::setState(bool state)
   if(_state != state)
   {
     _state = state;
-    setDirty(); draw();
+    setDirty();
   }
 }
 
@@ -541,7 +547,7 @@ void CheckboxWidget::drawWidget(bool hilite)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-SliderWidget::SliderWidget(GuiObject *boss, const GUI::Font& font,
+SliderWidget::SliderWidget(GuiObject* boss, const GUI::Font& font,
                            int x, int y, int w, int h,
                            const string& label, int labelWidth, int cmd)
   : ButtonWidget(boss, font, x, y, w, h, label, cmd),
@@ -571,7 +577,7 @@ void SliderWidget::setValue(int value)
   if(value != _value)
   {
     _value = value; 
-    setDirty(); draw();
+    setDirty();
     sendCommand(_cmd, _value, _id);
   }
 }
